
        .SPACE  $TEXT$,SORT=8
        .SUBSPA $CODE$,QUAD=0,ALIGN=8,ACCESS=44,CODE_ONLY,SORT=24
DesSmallCoreEncrypt
        .PROC
        .CALLINFO CALLER,FRAME=0,ENTRY_GR=9,ENTRY_SR=3,SAVE_RP
        .ENTRY
        STW     %r2,-20(0,%r30) ;offset 0x0
        STWM    %r3,64(0,%r30)  ;offset 0x4
        STW     %r4,-60(0,%r30) ;offset 0x8
        STW     %r5,-56(0,%r30) ;offset 0xc
        STW     %r6,-52(0,%r30) ;offset 0x10
        STW     %r7,-48(0,%r30) ;offset 0x14
        STW     %r8,-44(0,%r30) ;offset 0x18
        STW     %r9,-40(0,%r30) ;offset 0x1c
        LDB     7(0,%r24),%r6   ;offset 0x20
        LDB     6(0,%r24),%r2   ;offset 0x24
        LDB     3(0,%r24),%r1   ;offset 0x28
        ZDEP    %r6,23,24,%r9   ;offset 0x2c
        LDB     2(0,%r24),%r19  ;offset 0x30
        LDB     5(0,%r24),%r28  ;offset 0x34
        OR      %r9,%r2,%r22    ;offset 0x38
        ZDEP    %r1,23,24,%r3   ;offset 0x3c
        ZDEP    %r22,23,24,%r22 ;offset 0x40
        LDB     1(0,%r24),%r20  ;offset 0x44
        OR      %r22,%r28,%r31  ;offset 0x48
        OR      %r3,%r19,%r29   ;offset 0x4c
        ZDEP    %r31,23,24,%r8  ;offset 0x50
        ZDEP    %r29,23,24,%r29 ;offset 0x54
        LDB     4(0,%r24),%r9   ;offset 0x58
        LDB     0(0,%r24),%r31  ;offset 0x5c
        OR      %r29,%r20,%r19  ;offset 0x60
        ZDEP    %r19,23,24,%r23 ;offset 0x64
        ADDIL   LR'des_keymap-$global$,%r27     ;offset 0x68
        OR      %r8,%r9,%r2     ;offset 0x6c
        OR      %r23,%r31,%r3   ;offset 0x70
        LDW     0(0,%r25),%r24  ;offset 0x74
        LDO     RR'des_keymap-$global$+1024(%r1),%r31   ;offset 0x78
        LDO     RR'des_keymap-$global$+1280(%r1),%r23   ;offset 0x7c
        LDO     RR'des_keymap-$global$+1536(%r1),%r29   ;offset 0x80
        LDO     RR'des_keymap-$global$+1792(%r1),%r19   ;offset 0x84
        LDO     RR'des_keymap-$global$(%r1),%r20        ;offset 0x88
        LDO     RR'des_keymap-$global$+256(%r1),%r21    ;offset 0x8c
        LDO     RR'des_keymap-$global$+512(%r1),%r22    ;offset 0x90
        LDO     RR'des_keymap-$global$+768(%r1),%r28    ;offset 0x94
        EXTRU   %r2,30,31,%r6   ;offset 0x98
        ZDEP    %r2,0,1,%r8     ;offset 0x9c
        OR      %r6,%r8,%r1     ;offset 0xa0
        LDW     4(0,%r25),%r7   ;offset 0xa4
        XOR     %r24,%r1,%r2    ;offset 0xa8
        LDI     252,%r24        ;offset 0xac
        XOR     %r7,%r1,%r5     ;offset 0xb0
        AND     %r24,%r2,%r4    ;offset 0xb4
        ADD     %r28,%r4,%r7    ;offset 0xb8
        LDW     0(0,%r7),%r4    ;offset 0xbc
        EXTRU   %r2,23,24,%r8   ;offset 0xc0
        AND     %r24,%r8,%r7    ;offset 0xc4
        ADD     %r22,%r7,%r9    ;offset 0xc8
        EXTRU   %r2,15,16,%r6   ;offset 0xcc
        LDW     0(0,%r9),%r2    ;offset 0xd0
        EXTRU   %r3,30,31,%r7   ;offset 0xd4
        ZDEP    %r3,0,1,%r8     ;offset 0xd8
        ZDEP    %r5,27,28,%r3   ;offset 0xdc
        EXTRU   %r5,3,4,%r9     ;offset 0xe0
        AND     %r24,%r6,%r5    ;offset 0xe4
        EXTRU   %r6,23,24,%r6   ;offset 0xe8
        OR      %r7,%r8,%r7     ;offset 0xec
        XOR     %r7,%r4,%r8     ;offset 0xf0
        OR      %r3,%r9,%r3     ;offset 0xf4
        ADD     %r21,%r5,%r5    ;offset 0xf8
        AND     %r24,%r6,%r6    ;offset 0xfc
        LDW     0(0,%r5),%r7    ;offset 0x100
        ADD     %r20,%r6,%r4    ;offset 0x104
        AND     %r24,%r3,%r9    ;offset 0x108
        LDW     0(0,%r4),%r4    ;offset 0x10c
        XOR     %r8,%r2,%r2     ;offset 0x110
        ADD     %r19,%r9,%r5    ;offset 0x114
        LDW     0(0,%r5),%r8    ;offset 0x118
        EXTRU   %r3,23,24,%r6   ;offset 0x11c
        XOR     %r2,%r7,%r9     ;offset 0x120
        EXTRU   %r3,15,16,%r3   ;offset 0x124
        XOR     %r9,%r4,%r4     ;offset 0x128
        AND     %r24,%r6,%r6    ;offset 0x12c
        ADD     %r29,%r6,%r5    ;offset 0x130
        AND     %r24,%r3,%r2    ;offset 0x134
        XOR     %r4,%r8,%r4     ;offset 0x138
        LDW     0(0,%r5),%r9    ;offset 0x13c
        ADD     %r23,%r2,%r2    ;offset 0x140
        EXTRU   %r3,23,24,%r8   ;offset 0x144
        LDW     0(0,%r2),%r6    ;offset 0x148
        AND     %r24,%r8,%r3    ;offset 0x14c
        XOR     %r4,%r9,%r2     ;offset 0x150
        ADD     %r31,%r3,%r3    ;offset 0x154
        LDW     0(0,%r3),%r9    ;offset 0x158
        LDW     8(0,%r25),%r4   ;offset 0x15c
        XOR     %r2,%r6,%r2     ;offset 0x160
        XOR     %r2,%r9,%r3     ;offset 0x164
        XOR     %r4,%r3,%r8     ;offset 0x168
        EXTRU   %r8,23,24,%r7   ;offset 0x16c
        LDW     12(0,%r25),%r2  ;offset 0x170
        AND     %r24,%r8,%r9    ;offset 0x174
        AND     %r24,%r7,%r4    ;offset 0x178
        EXTRU   %r8,15,16,%r8   ;offset 0x17c
        ADD     %r22,%r4,%r7    ;offset 0x180
        ADD     %r28,%r9,%r9    ;offset 0x184
        LDW     0(0,%r9),%r5    ;offset 0x188
        XOR     %r2,%r3,%r2     ;offset 0x18c
        AND     %r24,%r8,%r6    ;offset 0x190
        EXTRU   %r8,23,24,%r4   ;offset 0x194
        ZDEP    %r2,27,28,%r8   ;offset 0x198
        EXTRU   %r2,3,4,%r9     ;offset 0x19c
        OR      %r8,%r9,%r2     ;offset 0x1a0
        LDW     0(0,%r7),%r7    ;offset 0x1a4
        ADD     %r21,%r6,%r8    ;offset 0x1a8
        AND     %r24,%r4,%r9    ;offset 0x1ac
        LDW     0(0,%r8),%r6    ;offset 0x1b0
        XOR     %r1,%r5,%r4     ;offset 0x1b4
        XOR     %r4,%r7,%r8     ;offset 0x1b8
        ADD     %r20,%r9,%r1    ;offset 0x1bc
        EXTRU   %r2,23,24,%r5   ;offset 0x1c0
        LDW     0(0,%r1),%r4    ;offset 0x1c4
        AND     %r24,%r2,%r9    ;offset 0x1c8
        AND     %r24,%r5,%r5    ;offset 0x1cc
        ADD     %r19,%r9,%r1    ;offset 0x1d0
        EXTRU   %r2,15,16,%r2   ;offset 0x1d4
        XOR     %r8,%r6,%r8     ;offset 0x1d8
        ADD     %r29,%r5,%r7    ;offset 0x1dc
        LDW     0(0,%r1),%r6    ;offset 0x1e0
        XOR     %r8,%r4,%r9     ;offset 0x1e4
        AND     %r24,%r2,%r5    ;offset 0x1e8
        LDW     0(0,%r7),%r8    ;offset 0x1ec
        EXTRU   %r2,23,24,%r1   ;offset 0x1f0
        ADD     %r23,%r5,%r5    ;offset 0x1f4
        LDW     0(0,%r5),%r5    ;offset 0x1f8
        AND     %r24,%r1,%r1    ;offset 0x1fc
        XOR     %r9,%r6,%r9     ;offset 0x200
        XOR     %r9,%r8,%r6     ;offset 0x204
        ADD     %r31,%r1,%r4    ;offset 0x208
        LDW     0(0,%r4),%r8    ;offset 0x20c
        XOR     %r6,%r5,%r2     ;offset 0x210
        LDW     16(0,%r25),%r5  ;offset 0x214
        XOR     %r2,%r8,%r1     ;offset 0x218
        XOR     %r5,%r1,%r5     ;offset 0x21c
        AND     %r24,%r5,%r6    ;offset 0x220
        EXTRU   %r5,23,24,%r9   ;offset 0x224
        ADD     %r28,%r6,%r2    ;offset 0x228
        LDW     20(0,%r25),%r8  ;offset 0x22c
        LDW     0(0,%r2),%r7    ;offset 0x230
        AND     %r24,%r9,%r9    ;offset 0x234
        EXTRU   %r5,15,16,%r6   ;offset 0x238
        ADD     %r22,%r9,%r2    ;offset 0x23c
        EXTRU   %r5,7,8,%r4     ;offset 0x240
        XOR     %r8,%r1,%r5     ;offset 0x244
        AND     %r24,%r6,%r9    ;offset 0x248
        ADD     %r21,%r9,%r6    ;offset 0x24c
        AND     %r24,%r4,%r8    ;offset 0x250
        LDW     0(0,%r6),%r4    ;offset 0x254
        XOR     %r3,%r7,%r6     ;offset 0x258
        LDW     0(0,%r2),%r2    ;offset 0x25c
        ADD     %r20,%r8,%r7    ;offset 0x260
        ZDEP    %r5,27,28,%r8   ;offset 0x264
        EXTRU   %r5,3,4,%r9     ;offset 0x268
        LDW     0(0,%r7),%r5    ;offset 0x26c
        XOR     %r6,%r2,%r2     ;offset 0x270
        OR      %r8,%r9,%r3     ;offset 0x274
        XOR     %r2,%r4,%r4     ;offset 0x278
        AND     %r24,%r3,%r6    ;offset 0x27c
        XOR     %r4,%r5,%r2     ;offset 0x280
        ADD     %r19,%r6,%r4    ;offset 0x284
        EXTRU   %r3,23,24,%r3   ;offset 0x288
        EXTRU   %r3,23,24,%r6   ;offset 0x28c
        AND     %r24,%r3,%r3    ;offset 0x290
        ADD     %r29,%r3,%r7    ;offset 0x294
        LDW     0(0,%r4),%r5    ;offset 0x298
        LDW     0(0,%r7),%r3    ;offset 0x29c
        EXTRU   %r6,23,24,%r9   ;offset 0x2a0
        AND     %r24,%r6,%r8    ;offset 0x2a4
        AND     %r24,%r9,%r7    ;offset 0x2a8
        XOR     %r2,%r5,%r9     ;offset 0x2ac
        ADD     %r23,%r8,%r4    ;offset 0x2b0
        LDW     0(0,%r4),%r8    ;offset 0x2b4
        ADD     %r31,%r7,%r2    ;offset 0x2b8
        LDW     0(0,%r2),%r7    ;offset 0x2bc
        XOR     %r9,%r3,%r9     ;offset 0x2c0
        LDW     24(0,%r25),%r6  ;offset 0x2c4
        XOR     %r9,%r8,%r8     ;offset 0x2c8
        LDW     28(0,%r25),%r5  ;offset 0x2cc
        XOR     %r8,%r7,%r3     ;offset 0x2d0
        XOR     %r6,%r3,%r6     ;offset 0x2d4
        EXTRU   %r6,23,24,%r4   ;offset 0x2d8
        XOR     %r5,%r3,%r2     ;offset 0x2dc
        AND     %r24,%r6,%r8    ;offset 0x2e0
        ADD     %r28,%r8,%r6    ;offset 0x2e4
        EXTRU   %r4,23,24,%r5   ;offset 0x2e8
        AND     %r24,%r4,%r7    ;offset 0x2ec
        LDW     0(0,%r6),%r4    ;offset 0x2f0
        ADD     %r22,%r7,%r6    ;offset 0x2f4
        ZDEP    %r2,27,28,%r7   ;offset 0x2f8
        EXTRU   %r2,3,4,%r9     ;offset 0x2fc
        AND     %r24,%r5,%r8    ;offset 0x300
        EXTRU   %r5,23,24,%r5   ;offset 0x304
        OR      %r7,%r9,%r7     ;offset 0x308
        AND     %r24,%r5,%r9    ;offset 0x30c
        ADD     %r21,%r8,%r2    ;offset 0x310
        LDW     0(0,%r2),%r5    ;offset 0x314
        LDW     0(0,%r6),%r6    ;offset 0x318
        XOR     %r1,%r4,%r2     ;offset 0x31c
        EXTRU   %r7,23,24,%r1   ;offset 0x320
        AND     %r24,%r7,%r4    ;offset 0x324
        XOR     %r2,%r6,%r7     ;offset 0x328
        ADD     %r20,%r9,%r9    ;offset 0x32c
        LDW     0(0,%r9),%r2    ;offset 0x330
        ADD     %r19,%r4,%r9    ;offset 0x334
        XOR     %r7,%r5,%r7     ;offset 0x338
        LDW     0(0,%r9),%r5    ;offset 0x33c
        EXTRU   %r1,23,24,%r8   ;offset 0x340
        AND     %r24,%r8,%r4    ;offset 0x344
        EXTRU   %r8,23,24,%r9   ;offset 0x348
        AND     %r24,%r1,%r1    ;offset 0x34c
        ADD     %r29,%r1,%r6    ;offset 0x350
        XOR     %r7,%r2,%r8     ;offset 0x354
        LDW     0(0,%r6),%r7    ;offset 0x358
        ADD     %r23,%r4,%r4    ;offset 0x35c
        AND     %r24,%r9,%r9    ;offset 0x360
        LDW     0(0,%r4),%r4    ;offset 0x364
        XOR     %r8,%r5,%r8     ;offset 0x368
        ADD     %r31,%r9,%r1    ;offset 0x36c
        LDW     0(0,%r1),%r6    ;offset 0x370
        XOR     %r8,%r7,%r2     ;offset 0x374
        LDW     32(0,%r25),%r7  ;offset 0x378
        XOR     %r2,%r4,%r1     ;offset 0x37c
        XOR     %r1,%r6,%r1     ;offset 0x380
        XOR     %r7,%r1,%r4     ;offset 0x384
        EXTRU   %r4,23,24,%r6   ;offset 0x388
        AND     %r24,%r4,%r5    ;offset 0x38c
        ADD     %r28,%r5,%r2    ;offset 0x390
        AND     %r24,%r6,%r7    ;offset 0x394
        LDW     0(0,%r2),%r5    ;offset 0x398
        ADD     %r22,%r7,%r9    ;offset 0x39c
        LDW     0(0,%r9),%r7    ;offset 0x3a0
        XOR     %r3,%r5,%r9     ;offset 0x3a4
        LDW     36(0,%r25),%r5  ;offset 0x3a8
        XOR     %r9,%r7,%r2     ;offset 0x3ac
        XOR     %r5,%r1,%r7     ;offset 0x3b0
        EXTRU   %r4,15,16,%r4   ;offset 0x3b4
        AND     %r24,%r4,%r3    ;offset 0x3b8
        EXTRU   %r4,23,24,%r5   ;offset 0x3bc
        ZDEP    %r7,27,28,%r6   ;offset 0x3c0
        EXTRU   %r7,3,4,%r8     ;offset 0x3c4
        OR      %r6,%r8,%r4     ;offset 0x3c8
        AND     %r24,%r5,%r5    ;offset 0x3cc
        ADD     %r20,%r5,%r6    ;offset 0x3d0
        EXTRU   %r4,23,24,%r5   ;offset 0x3d4
        ADD     %r21,%r3,%r3    ;offset 0x3d8
        AND     %r24,%r4,%r4    ;offset 0x3dc
        LDW     0(0,%r3),%r3    ;offset 0x3e0
        ADD     %r19,%r4,%r9    ;offset 0x3e4
        EXTRU   %r5,23,24,%r7   ;offset 0x3e8
        AND     %r24,%r5,%r8    ;offset 0x3ec
        LDW     0(0,%r9),%r5    ;offset 0x3f0
        XOR     %r2,%r3,%r9     ;offset 0x3f4
        LDW     0(0,%r6),%r6    ;offset 0x3f8
        ADD     %r29,%r8,%r2    ;offset 0x3fc
        EXTRU   %r7,23,24,%r8   ;offset 0x400
        AND     %r24,%r7,%r3    ;offset 0x404
        XOR     %r9,%r6,%r7     ;offset 0x408
        LDW     0(0,%r2),%r6    ;offset 0x40c
        ADD     %r23,%r3,%r2    ;offset 0x410
        AND     %r24,%r8,%r8    ;offset 0x414
        LDW     0(0,%r2),%r2    ;offset 0x418
        XOR     %r7,%r5,%r7     ;offset 0x41c
        ADD     %r31,%r8,%r9    ;offset 0x420
        LDW     0(0,%r9),%r5    ;offset 0x424
        XOR     %r7,%r6,%r6     ;offset 0x428
        LDW     40(0,%r25),%r8  ;offset 0x42c
        XOR     %r6,%r2,%r7     ;offset 0x430
        XOR     %r7,%r5,%r3     ;offset 0x434
        XOR     %r8,%r3,%r4     ;offset 0x438
        EXTRU   %r4,23,24,%r9   ;offset 0x43c
        AND     %r24,%r4,%r4    ;offset 0x440
        ADD     %r28,%r4,%r2    ;offset 0x444
        LDW     44(0,%r25),%r6  ;offset 0x448
        EXTRU   %r9,23,24,%r4   ;offset 0x44c
        AND     %r24,%r9,%r9    ;offset 0x450
        ADD     %r22,%r9,%r5    ;offset 0x454
        XOR     %r6,%r3,%r8     ;offset 0x458
        ZDEP    %r8,27,28,%r9   ;offset 0x45c
        EXTRU   %r8,3,4,%r8     ;offset 0x460
        AND     %r24,%r4,%r7    ;offset 0x464
        OR      %r9,%r8,%r6     ;offset 0x468
        EXTRU   %r4,23,24,%r4   ;offset 0x46c
        ADD     %r21,%r7,%r8    ;offset 0x470
        AND     %r24,%r4,%r7    ;offset 0x474
        LDW     0(0,%r2),%r2    ;offset 0x478
        LDW     0(0,%r8),%r4    ;offset 0x47c
        LDW     0(0,%r5),%r5    ;offset 0x480
        ADD     %r20,%r7,%r8    ;offset 0x484
        XOR     %r1,%r2,%r1     ;offset 0x488
        EXTRU   %r6,23,24,%r7   ;offset 0x48c
        AND     %r24,%r6,%r9    ;offset 0x490
        XOR     %r1,%r5,%r6     ;offset 0x494
        LDW     0(0,%r8),%r1    ;offset 0x498
        ADD     %r19,%r9,%r8    ;offset 0x49c
        EXTRU   %r7,23,24,%r5   ;offset 0x4a0
        XOR     %r6,%r4,%r6     ;offset 0x4a4
        LDW     0(0,%r8),%r4    ;offset 0x4a8
        AND     %r24,%r7,%r7    ;offset 0x4ac
        ADD     %r29,%r7,%r8    ;offset 0x4b0
        AND     %r24,%r5,%r2    ;offset 0x4b4
        EXTRU   %r5,23,24,%r7   ;offset 0x4b8
        LDW     0(0,%r8),%r5    ;offset 0x4bc
        ADD     %r23,%r2,%r9    ;offset 0x4c0
        XOR     %r6,%r1,%r6     ;offset 0x4c4
        AND     %r24,%r7,%r7    ;offset 0x4c8
        LDW     0(0,%r9),%r9    ;offset 0x4cc
        XOR     %r6,%r4,%r6     ;offset 0x4d0
        ADD     %r31,%r7,%r8    ;offset 0x4d4
        LDW     0(0,%r8),%r2    ;offset 0x4d8
        XOR     %r6,%r5,%r1     ;offset 0x4dc
        LDW     48(0,%r25),%r5  ;offset 0x4e0
        XOR     %r1,%r9,%r4     ;offset 0x4e4
        XOR     %r4,%r2,%r1     ;offset 0x4e8
        LDW     52(0,%r25),%r4  ;offset 0x4ec
        XOR     %r5,%r1,%r9     ;offset 0x4f0
        EXTRU   %r9,23,24,%r7   ;offset 0x4f4
        AND     %r24,%r9,%r2    ;offset 0x4f8
        XOR     %r4,%r1,%r6     ;offset 0x4fc
        ADD     %r28,%r2,%r9    ;offset 0x500
        ZDEP    %r6,27,28,%r2   ;offset 0x504
        EXTRU   %r7,23,24,%r8   ;offset 0x508
        EXTRU   %r6,3,4,%r6     ;offset 0x50c
        LDW     0(0,%r9),%r5    ;offset 0x510
        AND     %r24,%r8,%r4    ;offset 0x514
        OR      %r2,%r6,%r2     ;offset 0x518
        ADD     %r21,%r4,%r6    ;offset 0x51c
        AND     %r24,%r7,%r7    ;offset 0x520
        EXTRU   %r8,23,24,%r8   ;offset 0x524
        AND     %r24,%r8,%r4    ;offset 0x528
        XOR     %r3,%r5,%r3     ;offset 0x52c
        ADD     %r22,%r7,%r7    ;offset 0x530
        LDW     0(0,%r7),%r7    ;offset 0x534
        ADD     %r20,%r4,%r5    ;offset 0x538
        EXTRU   %r2,23,24,%r4   ;offset 0x53c
        LDW     0(0,%r6),%r6    ;offset 0x540
        XOR     %r3,%r7,%r8     ;offset 0x544
        AND     %r24,%r2,%r2    ;offset 0x548
        LDW     0(0,%r5),%r7    ;offset 0x54c
        EXTRU   %r4,23,24,%r3   ;offset 0x550
        ADD     %r19,%r2,%r2    ;offset 0x554
        AND     %r24,%r4,%r9    ;offset 0x558
        LDW     0(0,%r2),%r2    ;offset 0x55c
        ADD     %r29,%r9,%r4    ;offset 0x560
        XOR     %r8,%r6,%r8     ;offset 0x564
        EXTRU   %r3,23,24,%r5   ;offset 0x568
        LDW     0(0,%r4),%r4    ;offset 0x56c
        XOR     %r8,%r7,%r6     ;offset 0x570
        AND     %r24,%r3,%r9    ;offset 0x574
        AND     %r24,%r5,%r5    ;offset 0x578
        ADD     %r23,%r9,%r8    ;offset 0x57c
        XOR     %r6,%r2,%r6     ;offset 0x580
        ADD     %r31,%r5,%r7    ;offset 0x584
        LDW     0(0,%r8),%r8    ;offset 0x588
        XOR     %r6,%r4,%r5     ;offset 0x58c
        LDW     0(0,%r7),%r4    ;offset 0x590
        LDW     56(0,%r25),%r9  ;offset 0x594
        XOR     %r5,%r8,%r6     ;offset 0x598
        XOR     %r6,%r4,%r3     ;offset 0x59c
        LDW     60(0,%r25),%r7  ;offset 0x5a0
        XOR     %r9,%r3,%r2     ;offset 0x5a4
        AND     %r24,%r2,%r9    ;offset 0x5a8
        EXTRU   %r2,23,24,%r6   ;offset 0x5ac
        ADD     %r28,%r9,%r8    ;offset 0x5b0
        XOR     %r7,%r3,%r7     ;offset 0x5b4
        LDW     0(0,%r8),%r4    ;offset 0x5b8
        EXTRU   %r2,15,16,%r2   ;offset 0x5bc
        ZDEP    %r7,27,28,%r9   ;offset 0x5c0
        AND     %r24,%r2,%r5    ;offset 0x5c4
        AND     %r24,%r6,%r6    ;offset 0x5c8
        EXTRU   %r7,3,4,%r7     ;offset 0x5cc
        EXTRU   %r2,23,24,%r8   ;offset 0x5d0
        OR      %r9,%r7,%r2     ;offset 0x5d4
        ADD     %r22,%r6,%r6    ;offset 0x5d8
        LDW     0(0,%r6),%r7    ;offset 0x5dc
        AND     %r24,%r8,%r9    ;offset 0x5e0
        XOR     %r1,%r4,%r6     ;offset 0x5e4
        ADD     %r21,%r5,%r5    ;offset 0x5e8
        LDW     0(0,%r5),%r5    ;offset 0x5ec
        ADD     %r20,%r9,%r4    ;offset 0x5f0
        XOR     %r6,%r7,%r6     ;offset 0x5f4
        AND     %r24,%r2,%r8    ;offset 0x5f8
        LDW     0(0,%r4),%r7    ;offset 0x5fc
        ADD     %r19,%r8,%r8    ;offset 0x600
        LDW     0(0,%r8),%r9    ;offset 0x604
        XOR     %r6,%r5,%r1     ;offset 0x608
        XOR     %r1,%r7,%r5     ;offset 0x60c
        EXTRU   %r2,23,24,%r6   ;offset 0x610
        XOR     %r5,%r9,%r1     ;offset 0x614
        AND     %r24,%r6,%r4    ;offset 0x618
        ADD     %r29,%r4,%r9    ;offset 0x61c
        EXTRU   %r2,15,16,%r8   ;offset 0x620
        LDW     0(0,%r9),%r6    ;offset 0x624
        AND     %r24,%r8,%r4    ;offset 0x628
        EXTRU   %r2,7,8,%r7     ;offset 0x62c
        ADD     %r23,%r4,%r9    ;offset 0x630
        AND     %r24,%r7,%r8    ;offset 0x634
        LDW     0(0,%r9),%r2    ;offset 0x638
        ADD     %r31,%r8,%r7    ;offset 0x63c
        LDW     0(0,%r7),%r7    ;offset 0x640
        XOR     %r1,%r6,%r6     ;offset 0x644
        LDW     64(0,%r25),%r1  ;offset 0x648
        XOR     %r6,%r2,%r9     ;offset 0x64c
        XOR     %r9,%r7,%r2     ;offset 0x650
        XOR     %r1,%r2,%r6     ;offset 0x654
        LDW     68(0,%r25),%r8  ;offset 0x658
        EXTRU   %r6,23,24,%r5   ;offset 0x65c
        AND     %r24,%r6,%r7    ;offset 0x660
        ADD     %r28,%r7,%r6    ;offset 0x664
        LDW     0(0,%r6),%r1    ;offset 0x668
        XOR     %r8,%r2,%r4     ;offset 0x66c
        EXTRU   %r5,23,24,%r8   ;offset 0x670
        ZDEP    %r4,27,28,%r7   ;offset 0x674
        EXTRU   %r4,3,4,%r6     ;offset 0x678
        AND     %r24,%r8,%r4    ;offset 0x67c
        ADD     %r21,%r4,%r9    ;offset 0x680
        LDW     0(0,%r9),%r4    ;offset 0x684
        AND     %r24,%r5,%r5    ;offset 0x688
        EXTRU   %r8,23,24,%r8   ;offset 0x68c
        ADD     %r22,%r5,%r5    ;offset 0x690
        AND     %r24,%r8,%r8    ;offset 0x694
        XOR     %r3,%r1,%r9     ;offset 0x698
        LDW     0(0,%r5),%r5    ;offset 0x69c
        OR      %r7,%r6,%r7     ;offset 0x6a0
        ADD     %r20,%r8,%r1    ;offset 0x6a4
        EXTRU   %r7,23,24,%r8   ;offset 0x6a8
        AND     %r24,%r7,%r6    ;offset 0x6ac
        XOR     %r9,%r5,%r7     ;offset 0x6b0
        LDW     0(0,%r1),%r5    ;offset 0x6b4
        ADD     %r19,%r6,%r9    ;offset 0x6b8
        EXTRU   %r8,23,24,%r6   ;offset 0x6bc
        AND     %r24,%r8,%r3    ;offset 0x6c0
        XOR     %r7,%r4,%r7     ;offset 0x6c4
        LDW     0(0,%r9),%r1    ;offset 0x6c8
        AND     %r24,%r6,%r8    ;offset 0x6cc
        XOR     %r7,%r5,%r5     ;offset 0x6d0
        ADD     %r29,%r3,%r3    ;offset 0x6d4
        EXTRU   %r6,23,24,%r4   ;offset 0x6d8
        LDW     0(0,%r3),%r3    ;offset 0x6dc
        ADD     %r23,%r8,%r7    ;offset 0x6e0
        AND     %r24,%r4,%r4    ;offset 0x6e4
        LDW     0(0,%r7),%r7    ;offset 0x6e8
        XOR     %r5,%r1,%r5     ;offset 0x6ec
        ADD     %r31,%r4,%r6    ;offset 0x6f0
        XOR     %r5,%r3,%r4     ;offset 0x6f4
        LDW     0(0,%r6),%r3    ;offset 0x6f8
        XOR     %r4,%r7,%r5     ;offset 0x6fc
        LDW     72(0,%r25),%r4  ;offset 0x700
        XOR     %r5,%r3,%r1     ;offset 0x704
        XOR     %r4,%r1,%r3     ;offset 0x708
        EXTRU   %r3,23,24,%r7   ;offset 0x70c
        AND     %r24,%r3,%r3    ;offset 0x710
        ADD     %r28,%r3,%r5    ;offset 0x714
        LDW     0(0,%r5),%r8    ;offset 0x718
        AND     %r24,%r7,%r3    ;offset 0x71c
        ADD     %r22,%r3,%r5    ;offset 0x720
        LDW     0(0,%r5),%r5    ;offset 0x724
        EXTRU   %r7,23,24,%r4   ;offset 0x728
        XOR     %r2,%r8,%r8     ;offset 0x72c
        AND     %r24,%r4,%r3    ;offset 0x730
        XOR     %r8,%r5,%r2     ;offset 0x734
        LDW     76(0,%r25),%r5  ;offset 0x738
        ADD     %r21,%r3,%r6    ;offset 0x73c
        LDW     0(0,%r6),%r3    ;offset 0x740
        EXTRU   %r7,15,16,%r4   ;offset 0x744
        XOR     %r5,%r1,%r6     ;offset 0x748
        ZDEP    %r6,27,28,%r5   ;offset 0x74c
        EXTRU   %r6,3,4,%r7     ;offset 0x750
        AND     %r24,%r4,%r9    ;offset 0x754
        OR      %r5,%r7,%r8     ;offset 0x758
        ADD     %r20,%r9,%r4    ;offset 0x75c
        LDW     0(0,%r4),%r5    ;offset 0x760
        EXTRU   %r8,23,24,%r7   ;offset 0x764
        AND     %r24,%r8,%r9    ;offset 0x768
        ADD     %r19,%r9,%r4    ;offset 0x76c
        EXTRU   %r8,15,16,%r6   ;offset 0x770
        AND     %r24,%r7,%r7    ;offset 0x774
        LDW     0(0,%r4),%r4    ;offset 0x778
        XOR     %r2,%r3,%r8     ;offset 0x77c
        ADD     %r29,%r7,%r9    ;offset 0x780
        LDW     0(0,%r9),%r2    ;offset 0x784
        EXTRU   %r6,23,24,%r3   ;offset 0x788
        AND     %r24,%r6,%r7    ;offset 0x78c
        XOR     %r8,%r5,%r5     ;offset 0x790
        ADD     %r23,%r7,%r6    ;offset 0x794
        XOR     %r5,%r4,%r4     ;offset 0x798
        AND     %r24,%r3,%r3    ;offset 0x79c
        LDW     0(0,%r6),%r6    ;offset 0x7a0
        XOR     %r4,%r2,%r7     ;offset 0x7a4
        ADD     %r31,%r3,%r5    ;offset 0x7a8
        LDW     0(0,%r5),%r2    ;offset 0x7ac
        LDW     80(0,%r25),%r5  ;offset 0x7b0
        XOR     %r7,%r6,%r8     ;offset 0x7b4
        XOR     %r8,%r2,%r3     ;offset 0x7b8
        LDW     84(0,%r25),%r9  ;offset 0x7bc
        XOR     %r5,%r3,%r5     ;offset 0x7c0
        EXTRU   %r5,23,24,%r4   ;offset 0x7c4
        AND     %r24,%r5,%r6    ;offset 0x7c8
        XOR     %r9,%r3,%r2     ;offset 0x7cc
        ADD     %r28,%r6,%r5    ;offset 0x7d0
        AND     %r24,%r4,%r8    ;offset 0x7d4
        EXTRU   %r4,23,24,%r7   ;offset 0x7d8
        ZDEP    %r2,27,28,%r6   ;offset 0x7dc
        EXTRU   %r2,3,4,%r4     ;offset 0x7e0
        ADD     %r22,%r8,%r8    ;offset 0x7e4
        OR      %r6,%r4,%r6     ;offset 0x7e8
        LDW     0(0,%r8),%r4    ;offset 0x7ec
        AND     %r24,%r7,%r2    ;offset 0x7f0
        LDW     0(0,%r5),%r5    ;offset 0x7f4
        ADD     %r21,%r2,%r8    ;offset 0x7f8
        LDW     0(0,%r8),%r2    ;offset 0x7fc
        XOR     %r1,%r5,%r8     ;offset 0x800
        EXTRU   %r7,23,24,%r7   ;offset 0x804
        EXTRU   %r6,23,24,%r5   ;offset 0x808
        AND     %r24,%r7,%r9    ;offset 0x80c
        AND     %r24,%r6,%r1    ;offset 0x810
        ADD     %r20,%r9,%r7    ;offset 0x814
        XOR     %r8,%r4,%r6     ;offset 0x818
        LDW     0(0,%r7),%r4    ;offset 0x81c
        ADD     %r19,%r1,%r8    ;offset 0x820
        LDW     0(0,%r8),%r7    ;offset 0x824
        EXTRU   %r5,23,24,%r1   ;offset 0x828
        AND     %r24,%r5,%r9    ;offset 0x82c
        XOR     %r6,%r2,%r5     ;offset 0x830
        ADD     %r29,%r9,%r8    ;offset 0x834
        EXTRU   %r1,23,24,%r9   ;offset 0x838
        AND     %r24,%r1,%r6    ;offset 0x83c
        XOR     %r5,%r4,%r1     ;offset 0x840
        ADD     %r23,%r6,%r4    ;offset 0x844
        LDW     0(0,%r4),%r5    ;offset 0x848
        LDW     0(0,%r8),%r8    ;offset 0x84c
        AND     %r24,%r9,%r9    ;offset 0x850
        XOR     %r1,%r7,%r1     ;offset 0x854
        ADD     %r31,%r9,%r4    ;offset 0x858
        LDW     0(0,%r4),%r9    ;offset 0x85c
        XOR     %r1,%r8,%r1     ;offset 0x860
        LDW     88(0,%r25),%r2  ;offset 0x864
        XOR     %r1,%r5,%r1     ;offset 0x868
        LDW     92(0,%r25),%r4  ;offset 0x86c
        XOR     %r1,%r9,%r1     ;offset 0x870
        XOR     %r2,%r1,%r9     ;offset 0x874
        AND     %r24,%r9,%r5    ;offset 0x878
        XOR     %r4,%r1,%r7     ;offset 0x87c
        EXTRU   %r9,23,24,%r2   ;offset 0x880
        ADD     %r28,%r5,%r4    ;offset 0x884
        EXTRU   %r9,15,16,%r5   ;offset 0x888
        AND     %r24,%r2,%r6    ;offset 0x88c
        AND     %r24,%r5,%r2    ;offset 0x890
        EXTRU   %r9,7,8,%r8     ;offset 0x894
        LDW     0(0,%r4),%r4    ;offset 0x898
        ZDEP    %r7,27,28,%r9   ;offset 0x89c
        EXTRU   %r7,3,4,%r5     ;offset 0x8a0
        ADD     %r22,%r6,%r6    ;offset 0x8a4
        LDW     0(0,%r6),%r7    ;offset 0x8a8
        OR      %r9,%r5,%r5     ;offset 0x8ac
        XOR     %r3,%r4,%r9     ;offset 0x8b0
        ADD     %r21,%r2,%r2    ;offset 0x8b4
        LDW     0(0,%r2),%r6    ;offset 0x8b8
        XOR     %r9,%r7,%r3     ;offset 0x8bc
        AND     %r24,%r8,%r8    ;offset 0x8c0
        AND     %r24,%r5,%r4    ;offset 0x8c4
        ADD     %r20,%r8,%r2    ;offset 0x8c8
        ADD     %r19,%r4,%r7    ;offset 0x8cc
        XOR     %r3,%r6,%r3     ;offset 0x8d0
        EXTRU   %r5,23,24,%r8   ;offset 0x8d4
        EXTRU   %r5,15,16,%r4   ;offset 0x8d8
        LDW     0(0,%r7),%r6    ;offset 0x8dc
        LDW     0(0,%r2),%r2    ;offset 0x8e0
        AND     %r24,%r8,%r5    ;offset 0x8e4
        ADD     %r29,%r5,%r7    ;offset 0x8e8
        XOR     %r3,%r2,%r9     ;offset 0x8ec
        AND     %r24,%r4,%r5    ;offset 0x8f0
        LDW     0(0,%r7),%r7    ;offset 0x8f4
        EXTRU   %r4,23,24,%r8   ;offset 0x8f8
        ADD     %r23,%r5,%r2    ;offset 0x8fc
        LDW     0(0,%r2),%r4    ;offset 0x900
        AND     %r24,%r8,%r8    ;offset 0x904
        XOR     %r9,%r6,%r9     ;offset 0x908
        ADD     %r31,%r8,%r2    ;offset 0x90c
        XOR     %r9,%r7,%r6     ;offset 0x910
        LDW     0(0,%r2),%r8    ;offset 0x914
        XOR     %r6,%r4,%r7     ;offset 0x918
        LDW     96(0,%r25),%r6  ;offset 0x91c
        XOR     %r7,%r8,%r3     ;offset 0x920
        XOR     %r6,%r3,%r2     ;offset 0x924
        LDW     100(0,%r25),%r5 ;offset 0x928
        EXTRU   %r2,23,24,%r9   ;offset 0x92c
        AND     %r24,%r2,%r4    ;offset 0x930
        ADD     %r28,%r4,%r2    ;offset 0x934
        XOR     %r5,%r3,%r8     ;offset 0x938
        AND     %r24,%r9,%r4    ;offset 0x93c
        EXTRU   %r9,23,24,%r6   ;offset 0x940
        ADD     %r22,%r4,%r5    ;offset 0x944
        ZDEP    %r8,27,28,%r4   ;offset 0x948
        EXTRU   %r8,3,4,%r9     ;offset 0x94c
        AND     %r24,%r6,%r7    ;offset 0x950
        EXTRU   %r6,23,24,%r8   ;offset 0x954
        LDW     0(0,%r5),%r6    ;offset 0x958
        LDW     0(0,%r2),%r2    ;offset 0x95c
        OR      %r4,%r9,%r4     ;offset 0x960
        AND     %r24,%r8,%r5    ;offset 0x964
        ADD     %r21,%r7,%r9    ;offset 0x968
        LDW     0(0,%r9),%r8    ;offset 0x96c
        XOR     %r1,%r2,%r1     ;offset 0x970
        ADD     %r20,%r5,%r2    ;offset 0x974
        XOR     %r1,%r6,%r1     ;offset 0x978
        AND     %r24,%r4,%r9    ;offset 0x97c
        LDW     0(0,%r2),%r6    ;offset 0x980
        ADD     %r19,%r9,%r5    ;offset 0x984
        XOR     %r1,%r8,%r7     ;offset 0x988
        LDW     0(0,%r5),%r8    ;offset 0x98c
        XOR     %r7,%r6,%r9     ;offset 0x990
        EXTRU   %r4,23,24,%r2   ;offset 0x994
        XOR     %r9,%r8,%r1     ;offset 0x998
        EXTRU   %r4,15,16,%r6   ;offset 0x99c
        AND     %r24,%r2,%r2    ;offset 0x9a0
        ADD     %r29,%r2,%r7    ;offset 0x9a4
        AND     %r24,%r6,%r9    ;offset 0x9a8
        LDW     0(0,%r7),%r5    ;offset 0x9ac
        EXTRU   %r4,7,8,%r6     ;offset 0x9b0
        ADD     %r23,%r9,%r7    ;offset 0x9b4
        AND     %r24,%r6,%r2    ;offset 0x9b8
        LDW     0(0,%r7),%r9    ;offset 0x9bc
        ADD     %r31,%r2,%r6    ;offset 0x9c0
        LDW     0(0,%r6),%r6    ;offset 0x9c4
        XOR     %r1,%r5,%r1     ;offset 0x9c8
        LDW     104(0,%r25),%r7 ;offset 0x9cc
        XOR     %r1,%r9,%r8     ;offset 0x9d0
        XOR     %r8,%r6,%r4     ;offset 0x9d4
        XOR     %r7,%r4,%r8     ;offset 0x9d8
        LDW     108(0,%r25),%r6 ;offset 0x9dc
        EXTRU   %r8,23,24,%r7   ;offset 0x9e0
        AND     %r24,%r7,%r2    ;offset 0x9e4
        XOR     %r6,%r4,%r6     ;offset 0x9e8
        ADD     %r22,%r2,%r7    ;offset 0x9ec
        ZDEP    %r6,27,28,%r2   ;offset 0x9f0
        AND     %r24,%r8,%r9    ;offset 0x9f4
        EXTRU   %r8,15,16,%r5   ;offset 0x9f8
        EXTRU   %r6,3,4,%r6     ;offset 0x9fc
        AND     %r24,%r5,%r8    ;offset 0xa00
        ADD     %r28,%r9,%r9    ;offset 0xa04
        OR      %r2,%r6,%r2     ;offset 0xa08
        LDW     0(0,%r9),%r1    ;offset 0xa0c
        LDW     0(0,%r7),%r6    ;offset 0xa10
        EXTRU   %r5,23,24,%r5   ;offset 0xa14
        ADD     %r21,%r8,%r7    ;offset 0xa18
        AND     %r24,%r5,%r9    ;offset 0xa1c
        LDW     0(0,%r7),%r5    ;offset 0xa20
        XOR     %r3,%r1,%r8     ;offset 0xa24
        EXTRU   %r2,23,24,%r3   ;offset 0xa28
        AND     %r24,%r2,%r7    ;offset 0xa2c
        XOR     %r8,%r6,%r2     ;offset 0xa30
        ADD     %r20,%r9,%r1    ;offset 0xa34
        ADD     %r19,%r7,%r6    ;offset 0xa38
        XOR     %r2,%r5,%r2     ;offset 0xa3c
        LDW     0(0,%r6),%r5    ;offset 0xa40
        AND     %r24,%r3,%r9    ;offset 0xa44
        LDW     0(0,%r1),%r1    ;offset 0xa48
        ADD     %r29,%r9,%r6    ;offset 0xa4c
        EXTRU   %r3,23,24,%r8   ;offset 0xa50
        AND     %r24,%r8,%r9    ;offset 0xa54
        EXTRU   %r3,15,16,%r7   ;offset 0xa58
        LDW     0(0,%r6),%r6    ;offset 0xa5c
        XOR     %r2,%r1,%r8     ;offset 0xa60
        ADD     %r23,%r9,%r9    ;offset 0xa64
        AND     %r24,%r7,%r7    ;offset 0xa68
        LDW     0(0,%r9),%r3    ;offset 0xa6c
        XOR     %r8,%r5,%r8     ;offset 0xa70
        ADD     %r31,%r7,%r1    ;offset 0xa74
        LDW     0(0,%r1),%r7    ;offset 0xa78
        XOR     %r8,%r6,%r5     ;offset 0xa7c
        LDW     112(0,%r25),%r8 ;offset 0xa80
        XOR     %r5,%r3,%r6     ;offset 0xa84
        XOR     %r6,%r7,%r1     ;offset 0xa88
        XOR     %r8,%r1,%r2     ;offset 0xa8c
        EXTRU   %r2,23,24,%r5   ;offset 0xa90
        AND     %r24,%r2,%r9    ;offset 0xa94
        ADD     %r28,%r9,%r3    ;offset 0xa98
        AND     %r24,%r5,%r8    ;offset 0xa9c
        EXTRU   %r2,15,16,%r6   ;offset 0xaa0
        ADD     %r22,%r8,%r9    ;offset 0xaa4
        LDW     0(0,%r3),%r7    ;offset 0xaa8
        AND     %r24,%r6,%r8    ;offset 0xaac
        ADD     %r21,%r8,%r3    ;offset 0xab0
        LDW     0(0,%r9),%r2    ;offset 0xab4
        XOR     %r4,%r7,%r8     ;offset 0xab8
        LDW     0(0,%r3),%r3    ;offset 0xabc
        XOR     %r8,%r2,%r2     ;offset 0xac0
        XOR     %r2,%r3,%r3     ;offset 0xac4
        EXTRU   %r6,23,24,%r2   ;offset 0xac8
        AND     %r24,%r2,%r8    ;offset 0xacc
        LDW     116(0,%r25),%r7 ;offset 0xad0
        ADD     %r20,%r8,%r8    ;offset 0xad4
        LDW     0(0,%r8),%r4    ;offset 0xad8
        XOR     %r7,%r1,%r7     ;offset 0xadc
        ZDEP    %r7,27,28,%r8   ;offset 0xae0
        EXTRU   %r7,3,4,%r9     ;offset 0xae4
        OR      %r8,%r9,%r8     ;offset 0xae8
        EXTRU   %r8,23,24,%r6   ;offset 0xaec
        AND     %r24,%r8,%r8    ;offset 0xaf0
        ADD     %r19,%r8,%r5    ;offset 0xaf4
        EXTRU   %r6,23,24,%r8   ;offset 0xaf8
        AND     %r24,%r6,%r6    ;offset 0xafc
        ADD     %r29,%r6,%r7    ;offset 0xb00
        LDW     0(0,%r7),%r6    ;offset 0xb04
        AND     %r24,%r8,%r7    ;offset 0xb08
        EXTRU   %r8,23,24,%r9   ;offset 0xb0c
        LDW     0(0,%r5),%r5    ;offset 0xb10
        XOR     %r3,%r4,%r8     ;offset 0xb14
        ADD     %r23,%r7,%r7    ;offset 0xb18
        AND     %r24,%r9,%r3    ;offset 0xb1c
        ADD     %r31,%r3,%r9    ;offset 0xb20
        LDW     0(0,%r7),%r7    ;offset 0xb24
        XOR     %r8,%r5,%r8     ;offset 0xb28
        LDW     0(0,%r9),%r3    ;offset 0xb2c
        XOR     %r8,%r6,%r4     ;offset 0xb30
        LDW     120(0,%r25),%r2 ;offset 0xb34
        XOR     %r4,%r7,%r4     ;offset 0xb38
        XOR     %r4,%r3,%r4     ;offset 0xb3c
        LDW     124(0,%r25),%r25        ;offset 0xb40
        XOR     %r2,%r4,%r5     ;offset 0xb44
        EXTRU   %r5,23,24,%r2   ;offset 0xb48
        EXTRU   %r2,23,24,%r3   ;offset 0xb4c
        AND     %r24,%r5,%r8    ;offset 0xb50
        ADD     %r28,%r8,%r9    ;offset 0xb54
        LDW     0(0,%r9),%r28   ;offset 0xb58
        XOR     %r25,%r4,%r5    ;offset 0xb5c
        AND     %r24,%r2,%r7    ;offset 0xb60
        ADD     %r22,%r7,%r25   ;offset 0xb64
        LDW     0(0,%r25),%r2   ;offset 0xb68
        AND     %r24,%r3,%r6    ;offset 0xb6c
        ADD     %r21,%r6,%r6    ;offset 0xb70
        LDW     0(0,%r6),%r25   ;offset 0xb74
        ZDEP    %r5,27,28,%r22  ;offset 0xb78
        EXTRU   %r3,23,24,%r9   ;offset 0xb7c
        AND     %r24,%r9,%r8    ;offset 0xb80
        ADD     %r20,%r8,%r7    ;offset 0xb84
        EXTRU   %r5,3,4,%r5     ;offset 0xb88
        OR      %r22,%r5,%r6    ;offset 0xb8c
        LDW     0(0,%r7),%r5    ;offset 0xb90
        EXTRU   %r6,23,24,%r8   ;offset 0xb94
        AND     %r24,%r6,%r6    ;offset 0xb98
        ADD     %r19,%r6,%r21   ;offset 0xb9c
        LDW     0(0,%r21),%r6   ;offset 0xba0
        XOR     %r1,%r28,%r9    ;offset 0xba4
        EXTRU   %r8,23,24,%r19  ;offset 0xba8
        AND     %r24,%r8,%r20   ;offset 0xbac
        ADD     %r29,%r20,%r1   ;offset 0xbb0
        LDW     0(0,%r1),%r29   ;offset 0xbb4
        AND     %r24,%r19,%r28  ;offset 0xbb8
        ADD     %r23,%r28,%r8   ;offset 0xbbc
        LDW     0(0,%r8),%r23   ;offset 0xbc0
        XOR     %r9,%r2,%r9     ;offset 0xbc4
        XOR     %r9,%r25,%r7    ;offset 0xbc8
        EXTRU   %r19,23,24,%r22 ;offset 0xbcc
        XOR     %r7,%r5,%r8     ;offset 0xbd0
        AND     %r24,%r22,%r24  ;offset 0xbd4
        ADD     %r31,%r24,%r21  ;offset 0xbd8
        LDW     0(0,%r21),%r3   ;offset 0xbdc
        XOR     %r8,%r6,%r5     ;offset 0xbe0
        XOR     %r5,%r29,%r20   ;offset 0xbe4
        XOR     %r20,%r23,%r28  ;offset 0xbe8
        XOR     %r28,%r3,%r2    ;offset 0xbec
        ZDEP    %r4,30,31,%r7   ;offset 0xbf0
        EXTRU   %r4,0,1,%r1     ;offset 0xbf4
        OR      %r7,%r1,%r3     ;offset 0xbf8
        STBS    %r3,4(0,%r26)   ;offset 0xbfc
        EXTRU   %r3,23,24,%r5   ;offset 0xc00
        STBS    %r5,5(0,%r26)   ;offset 0xc04
        EXTRU   %r3,15,16,%r4   ;offset 0xc08
        STBS    %r4,6(0,%r26)   ;offset 0xc0c
        EXTRU   %r3,7,8,%r7     ;offset 0xc10
        STBS    %r7,7(0,%r26)   ;offset 0xc14
        ZDEP    %r2,30,31,%r21  ;offset 0xc18
        EXTRU   %r2,0,1,%r6     ;offset 0xc1c
        OR      %r21,%r6,%r8    ;offset 0xc20
        STBS    %r8,0(0,%r26)   ;offset 0xc24
        EXTRU   %r8,23,24,%r31  ;offset 0xc28
        STBS    %r31,1(0,%r26)  ;offset 0xc2c
        EXTRU   %r8,15,16,%r9   ;offset 0xc30
        STBS    %r9,2(0,%r26)   ;offset 0xc34
        EXTRU   %r8,7,8,%r23    ;offset 0xc38
        STBS    %r23,3(0,%r26)  ;offset 0xc3c
        LDW     -84(0,%r30),%r2 ;offset 0xc40
        LDW     -40(0,%r30),%r9 ;offset 0xc44
        LDW     -44(0,%r30),%r8 ;offset 0xc48
        LDW     -48(0,%r30),%r7 ;offset 0xc4c
        LDW     -52(0,%r30),%r6 ;offset 0xc50
        LDW     -56(0,%r30),%r5 ;offset 0xc54
        LDW     -60(0,%r30),%r4 ;offset 0xc58
        BV      %r0(%r2)        ;offset 0xc5c
        .EXIT
        LDWM    -64(0,%r30),%r3 ;offset 0xc60
        .PROCEND ;in=24,25,26;


        .SPACE  $TEXT$
        .SUBSPA $CODE$,QUAD=0,ALIGN=8,ACCESS=44,CODE_ONLY,SORT=24
DesSmallCoreDecrypt
        .PROC
        .CALLINFO CALLER,FRAME=0,ENTRY_GR=9,ENTRY_SR=3,SAVE_RP
        .ENTRY
        STW     %r2,-20(0,%r30) ;offset 0xc68
        STWM    %r3,64(0,%r30)  ;offset 0xc6c
        STW     %r4,-60(0,%r30) ;offset 0xc70
        STW     %r5,-56(0,%r30) ;offset 0xc74
        STW     %r6,-52(0,%r30) ;offset 0xc78
        STW     %r7,-48(0,%r30) ;offset 0xc7c
        STW     %r8,-44(0,%r30) ;offset 0xc80
        STW     %r9,-40(0,%r30) ;offset 0xc84
        LDB     7(0,%r24),%r23  ;offset 0xc88
        LDB     6(0,%r24),%r1   ;offset 0xc8c
        ZDEP    %r23,23,24,%r28 ;offset 0xc90
        LDB     5(0,%r24),%r2   ;offset 0xc94
        OR      %r28,%r1,%r29   ;offset 0xc98
        ZDEP    %r29,23,24,%r22 ;offset 0xc9c
        OR      %r22,%r2,%r19   ;offset 0xca0
        LDB     4(0,%r24),%r3   ;offset 0xca4
        LDB     3(0,%r24),%r28  ;offset 0xca8
        ZDEP    %r19,23,24,%r21 ;offset 0xcac
        LDB     2(0,%r24),%r19  ;offset 0xcb0
        OR      %r21,%r3,%r2    ;offset 0xcb4
        ZDEP    %r28,23,24,%r7  ;offset 0xcb8
        LDB     1(0,%r24),%r20  ;offset 0xcbc
        LDW     124(0,%r25),%r31        ;offset 0xcc0
        OR      %r7,%r19,%r1    ;offset 0xcc4
        EXTRU   %r2,30,31,%r23  ;offset 0xcc8
        ZDEP    %r2,0,1,%r21    ;offset 0xccc
        OR      %r23,%r21,%r3   ;offset 0xcd0
        ZDEP    %r1,23,24,%r29  ;offset 0xcd4
        LDB     0(0,%r24),%r5   ;offset 0xcd8
        ADDIL   LR'des_keymap-$global$,%r27     ;offset 0xcdc
        OR      %r29,%r20,%r6   ;offset 0xce0
        XOR     %r31,%r3,%r4    ;offset 0xce4
        ZDEP    %r6,23,24,%r6   ;offset 0xce8
        LDO     RR'des_keymap-$global$(%r1),%r31        ;offset 0xcec
        LDO     RR'des_keymap-$global$+256(%r1),%r23    ;offset 0xcf0
        LDO     RR'des_keymap-$global$+512(%r1),%r29    ;offset 0xcf4
        LDO     RR'des_keymap-$global$+768(%r1),%r19    ;offset 0xcf8
        LDO     RR'des_keymap-$global$+1024(%r1),%r20   ;offset 0xcfc
        LDO     RR'des_keymap-$global$+1280(%r1),%r21   ;offset 0xd00
        LDO     RR'des_keymap-$global$+1536(%r1),%r22   ;offset 0xd04
        LDO     RR'des_keymap-$global$+1792(%r1),%r28   ;offset 0xd08
        ZDEP    %r4,27,28,%r9   ;offset 0xd0c
        EXTRU   %r4,3,4,%r7     ;offset 0xd10
        OR      %r9,%r7,%r1     ;offset 0xd14
        OR      %r6,%r5,%r5     ;offset 0xd18
        LDI     252,%r24        ;offset 0xd1c
        LDW     120(0,%r25),%r6 ;offset 0xd20
        AND     %r24,%r1,%r4    ;offset 0xd24
        EXTRU   %r1,23,24,%r8   ;offset 0xd28
        ADD     %r28,%r4,%r7    ;offset 0xd2c
        AND     %r24,%r8,%r8    ;offset 0xd30
        XOR     %r6,%r3,%r4     ;offset 0xd34
        ADD     %r22,%r8,%r6    ;offset 0xd38
        EXTRU   %r1,15,16,%r1   ;offset 0xd3c
        EXTRU   %r5,30,31,%r8   ;offset 0xd40
        ZDEP    %r5,0,1,%r9     ;offset 0xd44
        AND     %r24,%r1,%r2    ;offset 0xd48
        EXTRU   %r1,23,24,%r5   ;offset 0xd4c
        OR      %r8,%r9,%r8     ;offset 0xd50
        LDW     0(0,%r7),%r7    ;offset 0xd54
        ADD     %r21,%r2,%r9    ;offset 0xd58
        AND     %r24,%r5,%r5    ;offset 0xd5c
        LDW     0(0,%r6),%r1    ;offset 0xd60
        ADD     %r20,%r5,%r2    ;offset 0xd64
        LDW     0(0,%r9),%r6    ;offset 0xd68
        XOR     %r8,%r7,%r7     ;offset 0xd6c
        EXTRU   %r4,23,24,%r5   ;offset 0xd70
        AND     %r24,%r4,%r4    ;offset 0xd74
        XOR     %r7,%r1,%r7     ;offset 0xd78
        LDW     0(0,%r2),%r2    ;offset 0xd7c
        ADD     %r19,%r4,%r8    ;offset 0xd80
        XOR     %r7,%r6,%r1     ;offset 0xd84
        LDW     0(0,%r8),%r7    ;offset 0xd88
        EXTRU   %r5,23,24,%r4   ;offset 0xd8c
        AND     %r24,%r5,%r9    ;offset 0xd90
        ADD     %r29,%r9,%r5    ;offset 0xd94
        AND     %r24,%r4,%r6    ;offset 0xd98
        XOR     %r1,%r2,%r8     ;offset 0xd9c
        LDW     0(0,%r5),%r5    ;offset 0xda0
        XOR     %r8,%r7,%r8     ;offset 0xda4
        ADD     %r23,%r6,%r9    ;offset 0xda8
        LDW     0(0,%r9),%r6    ;offset 0xdac
        EXTRU   %r4,23,24,%r7   ;offset 0xdb0
        XOR     %r8,%r5,%r5     ;offset 0xdb4
        AND     %r24,%r7,%r2    ;offset 0xdb8
        XOR     %r5,%r6,%r1     ;offset 0xdbc
        ADD     %r31,%r2,%r2    ;offset 0xdc0
        LDW     0(0,%r2),%r6    ;offset 0xdc4
        LDW     116(0,%r25),%r9 ;offset 0xdc8
        XOR     %r1,%r6,%r4     ;offset 0xdcc
        XOR     %r9,%r4,%r9     ;offset 0xdd0
        ZDEP    %r9,27,28,%r8   ;offset 0xdd4
        EXTRU   %r9,3,4,%r6     ;offset 0xdd8
        OR      %r8,%r6,%r5     ;offset 0xddc
        EXTRU   %r5,23,24,%r8   ;offset 0xde0
        AND     %r24,%r5,%r5    ;offset 0xde4
        LDW     112(0,%r25),%r2 ;offset 0xde8
        ADD     %r28,%r5,%r1    ;offset 0xdec
        AND     %r24,%r8,%r6    ;offset 0xdf0
        ADD     %r22,%r6,%r7    ;offset 0xdf4
        EXTRU   %r8,23,24,%r5   ;offset 0xdf8
        AND     %r24,%r5,%r8    ;offset 0xdfc
        XOR     %r2,%r4,%r6     ;offset 0xe00
        EXTRU   %r5,23,24,%r5   ;offset 0xe04
        ADD     %r21,%r8,%r2    ;offset 0xe08
        LDW     0(0,%r1),%r1    ;offset 0xe0c
        AND     %r24,%r5,%r8    ;offset 0xe10
        LDW     0(0,%r2),%r5    ;offset 0xe14
        XOR     %r3,%r1,%r2     ;offset 0xe18
        LDW     0(0,%r7),%r7    ;offset 0xe1c
        EXTRU   %r6,23,24,%r1   ;offset 0xe20
        AND     %r24,%r6,%r9    ;offset 0xe24
        ADD     %r20,%r8,%r8    ;offset 0xe28
        LDW     0(0,%r8),%r6    ;offset 0xe2c
        XOR     %r2,%r7,%r7     ;offset 0xe30
        EXTRU   %r1,23,24,%r8   ;offset 0xe34
        AND     %r24,%r1,%r3    ;offset 0xe38
        XOR     %r7,%r5,%r1     ;offset 0xe3c
        ADD     %r19,%r9,%r2    ;offset 0xe40
        LDW     0(0,%r2),%r7    ;offset 0xe44
        ADD     %r29,%r3,%r5    ;offset 0xe48
        EXTRU   %r8,23,24,%r2   ;offset 0xe4c
        AND     %r24,%r8,%r3    ;offset 0xe50
        XOR     %r1,%r6,%r8     ;offset 0xe54
        LDW     0(0,%r5),%r5    ;offset 0xe58
        ADD     %r23,%r3,%r1    ;offset 0xe5c
        LDW     0(0,%r1),%r6    ;offset 0xe60
        AND     %r24,%r2,%r9    ;offset 0xe64
        XOR     %r8,%r7,%r3     ;offset 0xe68
        XOR     %r3,%r5,%r5     ;offset 0xe6c
        ADD     %r31,%r9,%r1    ;offset 0xe70
        LDW     0(0,%r1),%r3    ;offset 0xe74
        LDW     108(0,%r25),%r2 ;offset 0xe78
        XOR     %r5,%r6,%r5     ;offset 0xe7c
        XOR     %r5,%r3,%r1     ;offset 0xe80
        XOR     %r2,%r1,%r3     ;offset 0xe84
        ZDEP    %r3,27,28,%r7   ;offset 0xe88
        EXTRU   %r3,3,4,%r5     ;offset 0xe8c
        OR      %r7,%r5,%r3     ;offset 0xe90
        EXTRU   %r3,23,24,%r5   ;offset 0xe94
        AND     %r24,%r3,%r3    ;offset 0xe98
        ADD     %r28,%r3,%r2    ;offset 0xe9c
        AND     %r24,%r5,%r8    ;offset 0xea0
        LDW     0(0,%r2),%r7    ;offset 0xea4
        EXTRU   %r5,23,24,%r6   ;offset 0xea8
        ADD     %r22,%r8,%r8    ;offset 0xeac
        LDW     0(0,%r8),%r2    ;offset 0xeb0
        AND     %r24,%r6,%r3    ;offset 0xeb4
        ADD     %r21,%r3,%r8    ;offset 0xeb8
        EXTRU   %r5,15,16,%r5   ;offset 0xebc
        AND     %r24,%r5,%r3    ;offset 0xec0
        XOR     %r4,%r7,%r7     ;offset 0xec4
        LDW     104(0,%r25),%r6 ;offset 0xec8
        LDW     0(0,%r8),%r8    ;offset 0xecc
        XOR     %r7,%r2,%r5     ;offset 0xed0
        ADD     %r20,%r3,%r3    ;offset 0xed4
        LDW     0(0,%r3),%r7    ;offset 0xed8
        XOR     %r6,%r1,%r3     ;offset 0xedc
        XOR     %r5,%r8,%r9     ;offset 0xee0
        AND     %r24,%r3,%r8    ;offset 0xee4
        EXTRU   %r3,15,16,%r5   ;offset 0xee8
        EXTRU   %r3,23,24,%r6   ;offset 0xeec
        AND     %r24,%r6,%r3    ;offset 0xef0
        XOR     %r9,%r7,%r2     ;offset 0xef4
        ADD     %r19,%r8,%r4    ;offset 0xef8
        ADD     %r29,%r3,%r6    ;offset 0xefc
        LDW     0(0,%r4),%r3    ;offset 0xf00
        AND     %r24,%r5,%r9    ;offset 0xf04
        LDW     0(0,%r6),%r8    ;offset 0xf08
        EXTRU   %r5,23,24,%r4   ;offset 0xf0c
        ADD     %r23,%r9,%r9    ;offset 0xf10
        LDW     0(0,%r9),%r6    ;offset 0xf14
        AND     %r24,%r4,%r4    ;offset 0xf18
        XOR     %r2,%r3,%r7     ;offset 0xf1c
        ADD     %r31,%r4,%r9    ;offset 0xf20
        LDW     0(0,%r9),%r2    ;offset 0xf24
        XOR     %r7,%r8,%r3     ;offset 0xf28
        LDW     100(0,%r25),%r4 ;offset 0xf2c
        XOR     %r3,%r6,%r5     ;offset 0xf30
        XOR     %r5,%r2,%r3     ;offset 0xf34
        XOR     %r4,%r3,%r7     ;offset 0xf38
        ZDEP    %r7,27,28,%r6   ;offset 0xf3c
        EXTRU   %r7,3,4,%r4     ;offset 0xf40
        OR      %r6,%r4,%r2     ;offset 0xf44
        EXTRU   %r2,23,24,%r7   ;offset 0xf48
        AND     %r24,%r2,%r2    ;offset 0xf4c
        AND     %r24,%r7,%r5    ;offset 0xf50
        ADD     %r28,%r2,%r9    ;offset 0xf54
        EXTRU   %r7,23,24,%r2   ;offset 0xf58
        ADD     %r22,%r5,%r6    ;offset 0xf5c
        LDW     0(0,%r9),%r7    ;offset 0xf60
        AND     %r24,%r2,%r5    ;offset 0xf64
        EXTRU   %r2,23,24,%r8   ;offset 0xf68
        ADD     %r21,%r5,%r9    ;offset 0xf6c
        LDW     96(0,%r25),%r4  ;offset 0xf70
        AND     %r24,%r8,%r5    ;offset 0xf74
        XOR     %r1,%r7,%r8     ;offset 0xf78
        LDW     0(0,%r9),%r2    ;offset 0xf7c
        LDW     0(0,%r6),%r6    ;offset 0xf80
        XOR     %r4,%r3,%r4     ;offset 0xf84
        ADD     %r20,%r5,%r7    ;offset 0xf88
        EXTRU   %r4,23,24,%r5   ;offset 0xf8c
        AND     %r24,%r4,%r9    ;offset 0xf90
        LDW     0(0,%r7),%r4    ;offset 0xf94
        XOR     %r8,%r6,%r6     ;offset 0xf98
        ADD     %r19,%r9,%r7    ;offset 0xf9c
        EXTRU   %r5,23,24,%r1   ;offset 0xfa0
        XOR     %r6,%r2,%r6     ;offset 0xfa4
        AND     %r24,%r5,%r8    ;offset 0xfa8
        LDW     0(0,%r7),%r5    ;offset 0xfac
        AND     %r24,%r1,%r2    ;offset 0xfb0
        ADD     %r29,%r8,%r7    ;offset 0xfb4
        XOR     %r6,%r4,%r6     ;offset 0xfb8
        ADD     %r23,%r2,%r9    ;offset 0xfbc
        LDW     0(0,%r7),%r4    ;offset 0xfc0
        XOR     %r6,%r5,%r2     ;offset 0xfc4
        EXTRU   %r1,23,24,%r8   ;offset 0xfc8
        LDW     0(0,%r9),%r5    ;offset 0xfcc
        AND     %r24,%r8,%r8    ;offset 0xfd0
        ADD     %r31,%r8,%r7    ;offset 0xfd4
        XOR     %r2,%r4,%r2     ;offset 0xfd8
        LDW     0(0,%r7),%r9    ;offset 0xfdc
        XOR     %r2,%r5,%r2     ;offset 0xfe0
        LDW     92(0,%r25),%r5  ;offset 0xfe4
        XOR     %r2,%r9,%r1     ;offset 0xfe8
        XOR     %r5,%r1,%r2     ;offset 0xfec
        ZDEP    %r2,27,28,%r5   ;offset 0xff0
        EXTRU   %r2,3,4,%r2     ;offset 0xff4
        OR      %r5,%r2,%r9     ;offset 0xff8
        EXTRU   %r9,23,24,%r8   ;offset 0xffc
        AND     %r24,%r9,%r9    ;offset 0x1000
        ADD     %r28,%r9,%r2    ;offset 0x1004
        AND     %r24,%r8,%r5    ;offset 0x1008
        LDW     0(0,%r2),%r4    ;offset 0x100c
        ADD     %r22,%r5,%r7    ;offset 0x1010
        LDW     0(0,%r7),%r2    ;offset 0x1014
        XOR     %r3,%r4,%r3     ;offset 0x1018
        XOR     %r3,%r2,%r2     ;offset 0x101c
        LDW     88(0,%r25),%r6  ;offset 0x1020
        EXTRU   %r8,23,24,%r3   ;offset 0x1024
        AND     %r24,%r3,%r9    ;offset 0x1028
        EXTRU   %r8,15,16,%r4   ;offset 0x102c
        XOR     %r6,%r1,%r3     ;offset 0x1030
        ADD     %r21,%r9,%r5    ;offset 0x1034
        LDW     0(0,%r5),%r6    ;offset 0x1038
        EXTRU   %r3,23,24,%r8   ;offset 0x103c
        AND     %r24,%r4,%r4    ;offset 0x1040
        AND     %r24,%r8,%r9    ;offset 0x1044
        ADD     %r20,%r4,%r4    ;offset 0x1048
        AND     %r24,%r3,%r3    ;offset 0x104c
        EXTRU   %r8,23,24,%r7   ;offset 0x1050
        LDW     0(0,%r4),%r5    ;offset 0x1054
        XOR     %r2,%r6,%r6     ;offset 0x1058
        AND     %r24,%r7,%r8    ;offset 0x105c
        ADD     %r19,%r3,%r3    ;offset 0x1060
        LDW     0(0,%r3),%r4    ;offset 0x1064
        ADD     %r29,%r9,%r2    ;offset 0x1068
        EXTRU   %r7,23,24,%r7   ;offset 0x106c
        LDW     0(0,%r2),%r2    ;offset 0x1070
        XOR     %r6,%r5,%r5     ;offset 0x1074
        ADD     %r23,%r8,%r8    ;offset 0x1078
        AND     %r24,%r7,%r7    ;offset 0x107c
        LDW     0(0,%r8),%r3    ;offset 0x1080
        XOR     %r5,%r4,%r4     ;offset 0x1084
        ADD     %r31,%r7,%r6    ;offset 0x1088
        LDW     0(0,%r6),%r8    ;offset 0x108c
        XOR     %r4,%r2,%r2     ;offset 0x1090
        LDW     84(0,%r25),%r6  ;offset 0x1094
        XOR     %r2,%r3,%r3     ;offset 0x1098
        XOR     %r3,%r8,%r3     ;offset 0x109c
        XOR     %r6,%r3,%r5     ;offset 0x10a0
        ZDEP    %r5,27,28,%r4   ;offset 0x10a4
        EXTRU   %r5,3,4,%r9     ;offset 0x10a8
        OR      %r4,%r9,%r7     ;offset 0x10ac
        EXTRU   %r7,23,24,%r6   ;offset 0x10b0
        AND     %r24,%r7,%r8    ;offset 0x10b4
        LDW     80(0,%r25),%r7  ;offset 0x10b8
        EXTRU   %r6,23,24,%r5   ;offset 0x10bc
        AND     %r24,%r6,%r9    ;offset 0x10c0
        ADD     %r28,%r8,%r8    ;offset 0x10c4
        LDW     0(0,%r8),%r6    ;offset 0x10c8
        AND     %r24,%r5,%r8    ;offset 0x10cc
        XOR     %r7,%r3,%r2     ;offset 0x10d0
        EXTRU   %r5,23,24,%r4   ;offset 0x10d4
        ADD     %r21,%r8,%r7    ;offset 0x10d8
        AND     %r24,%r4,%r8    ;offset 0x10dc
        XOR     %r1,%r6,%r4     ;offset 0x10e0
        ADD     %r22,%r9,%r9    ;offset 0x10e4
        LDW     0(0,%r9),%r5    ;offset 0x10e8
        ADD     %r20,%r8,%r1    ;offset 0x10ec
        EXTRU   %r2,23,24,%r8   ;offset 0x10f0
        AND     %r24,%r2,%r6    ;offset 0x10f4
        LDW     0(0,%r7),%r7    ;offset 0x10f8
        XOR     %r4,%r5,%r2     ;offset 0x10fc
        ADD     %r19,%r6,%r4    ;offset 0x1100
        LDW     0(0,%r1),%r1    ;offset 0x1104
        XOR     %r2,%r7,%r5     ;offset 0x1108
        EXTRU   %r8,23,24,%r6   ;offset 0x110c
        AND     %r24,%r8,%r9    ;offset 0x1110
        LDW     0(0,%r4),%r4    ;offset 0x1114
        ADD     %r29,%r9,%r8    ;offset 0x1118
        AND     %r24,%r6,%r7    ;offset 0x111c
        LDW     0(0,%r8),%r8    ;offset 0x1120
        EXTRU   %r6,23,24,%r6   ;offset 0x1124
        XOR     %r5,%r1,%r5     ;offset 0x1128
        XOR     %r5,%r4,%r1     ;offset 0x112c
        ADD     %r23,%r7,%r7    ;offset 0x1130
        AND     %r24,%r6,%r6    ;offset 0x1134
        LDW     0(0,%r7),%r9    ;offset 0x1138
        ADD     %r31,%r6,%r5    ;offset 0x113c
        XOR     %r1,%r8,%r1     ;offset 0x1140
        LDW     0(0,%r5),%r8    ;offset 0x1144
        LDW     76(0,%r25),%r6  ;offset 0x1148
        XOR     %r1,%r9,%r4     ;offset 0x114c
        XOR     %r4,%r8,%r1     ;offset 0x1150
        XOR     %r6,%r1,%r5     ;offset 0x1154
        ZDEP    %r5,27,28,%r4   ;offset 0x1158
        EXTRU   %r5,3,4,%r8     ;offset 0x115c
        OR      %r4,%r8,%r6     ;offset 0x1160
        EXTRU   %r6,23,24,%r7   ;offset 0x1164
        EXTRU   %r7,23,24,%r4   ;offset 0x1168
        AND     %r24,%r6,%r9    ;offset 0x116c
        ADD     %r28,%r9,%r6    ;offset 0x1170
        AND     %r24,%r7,%r7    ;offset 0x1174
        LDW     0(0,%r6),%r5    ;offset 0x1178
        ADD     %r22,%r7,%r8    ;offset 0x117c
        LDW     72(0,%r25),%r2  ;offset 0x1180
        AND     %r24,%r4,%r6    ;offset 0x1184
        EXTRU   %r4,23,24,%r7   ;offset 0x1188
        LDW     0(0,%r8),%r4    ;offset 0x118c
        ADD     %r21,%r6,%r9    ;offset 0x1190
        LDW     0(0,%r9),%r6    ;offset 0x1194
        XOR     %r2,%r1,%r2     ;offset 0x1198
        XOR     %r3,%r5,%r3     ;offset 0x119c
        AND     %r24,%r7,%r7    ;offset 0x11a0
        EXTRU   %r2,23,24,%r5   ;offset 0x11a4
        XOR     %r3,%r4,%r4     ;offset 0x11a8
        ADD     %r20,%r7,%r7    ;offset 0x11ac
        LDW     0(0,%r7),%r7    ;offset 0x11b0
        XOR     %r4,%r6,%r4     ;offset 0x11b4
        AND     %r24,%r2,%r8    ;offset 0x11b8
        AND     %r24,%r5,%r5    ;offset 0x11bc
        EXTRU   %r2,15,16,%r3   ;offset 0x11c0
        ADD     %r29,%r5,%r6    ;offset 0x11c4
        ADD     %r19,%r8,%r8    ;offset 0x11c8
        LDW     0(0,%r8),%r2    ;offset 0x11cc
        AND     %r24,%r3,%r5    ;offset 0x11d0
        XOR     %r4,%r7,%r4     ;offset 0x11d4
        LDW     0(0,%r6),%r7    ;offset 0x11d8
        EXTRU   %r3,23,24,%r3   ;offset 0x11dc
        ADD     %r23,%r5,%r5    ;offset 0x11e0
        LDW     0(0,%r5),%r8    ;offset 0x11e4
        XOR     %r4,%r2,%r9     ;offset 0x11e8
        AND     %r24,%r3,%r3    ;offset 0x11ec
        XOR     %r9,%r7,%r9     ;offset 0x11f0
        ADD     %r31,%r3,%r4    ;offset 0x11f4
        LDW     0(0,%r4),%r7    ;offset 0x11f8
        XOR     %r9,%r8,%r2     ;offset 0x11fc
        LDW     68(0,%r25),%r8  ;offset 0x1200
        XOR     %r2,%r7,%r3     ;offset 0x1204
        XOR     %r8,%r3,%r4     ;offset 0x1208
        ZDEP    %r4,27,28,%r2   ;offset 0x120c
        EXTRU   %r4,3,4,%r8     ;offset 0x1210
        OR      %r2,%r8,%r6     ;offset 0x1214
        EXTRU   %r6,23,24,%r4   ;offset 0x1218
        AND     %r24,%r6,%r7    ;offset 0x121c
        ADD     %r28,%r7,%r6    ;offset 0x1220
        EXTRU   %r4,23,24,%r2   ;offset 0x1224
        AND     %r24,%r4,%r5    ;offset 0x1228
        LDW     64(0,%r25),%r7  ;offset 0x122c
        LDW     0(0,%r6),%r4    ;offset 0x1230
        ADD     %r22,%r5,%r9    ;offset 0x1234
        LDW     0(0,%r9),%r5    ;offset 0x1238
        AND     %r24,%r2,%r6    ;offset 0x123c
        EXTRU   %r2,23,24,%r8   ;offset 0x1240
        ADD     %r21,%r6,%r9    ;offset 0x1244
        XOR     %r7,%r3,%r2     ;offset 0x1248
        LDW     0(0,%r9),%r6    ;offset 0x124c
        XOR     %r1,%r4,%r7     ;offset 0x1250
        AND     %r24,%r8,%r8    ;offset 0x1254
        XOR     %r7,%r5,%r9     ;offset 0x1258
        ADD     %r20,%r8,%r4    ;offset 0x125c
        AND     %r24,%r2,%r1    ;offset 0x1260
        LDW     0(0,%r4),%r4    ;offset 0x1264
        XOR     %r9,%r6,%r5     ;offset 0x1268
        ADD     %r19,%r1,%r7    ;offset 0x126c
        LDW     0(0,%r7),%r6    ;offset 0x1270
        XOR     %r5,%r4,%r9     ;offset 0x1274
        XOR     %r9,%r6,%r1     ;offset 0x1278
        EXTRU   %r2,23,24,%r7   ;offset 0x127c
        EXTRU   %r2,15,16,%r4   ;offset 0x1280
        AND     %r24,%r7,%r6    ;offset 0x1284
        ADD     %r29,%r6,%r5    ;offset 0x1288
        AND     %r24,%r4,%r8    ;offset 0x128c
        EXTRU   %r2,7,8,%r9     ;offset 0x1290
        LDW     0(0,%r5),%r6    ;offset 0x1294
        ADD     %r23,%r8,%r4    ;offset 0x1298
        AND     %r24,%r9,%r2    ;offset 0x129c
        LDW     0(0,%r4),%r9    ;offset 0x12a0
        ADD     %r31,%r2,%r2    ;offset 0x12a4
        XOR     %r1,%r6,%r1     ;offset 0x12a8
        LDW     0(0,%r2),%r8    ;offset 0x12ac
        XOR     %r1,%r9,%r1     ;offset 0x12b0
        LDW     60(0,%r25),%r9  ;offset 0x12b4
        XOR     %r1,%r8,%r4     ;offset 0x12b8
        XOR     %r9,%r4,%r1     ;offset 0x12bc
        ZDEP    %r1,27,28,%r9   ;offset 0x12c0
        EXTRU   %r1,3,4,%r7     ;offset 0x12c4
        OR      %r9,%r7,%r5     ;offset 0x12c8
        EXTRU   %r5,23,24,%r9   ;offset 0x12cc
        AND     %r24,%r5,%r5    ;offset 0x12d0
        ADD     %r28,%r5,%r5    ;offset 0x12d4
        LDW     56(0,%r25),%r8  ;offset 0x12d8
        LDW     0(0,%r5),%r6    ;offset 0x12dc
        EXTRU   %r9,23,24,%r1   ;offset 0x12e0
        AND     %r24,%r1,%r2    ;offset 0x12e4
        EXTRU   %r1,23,24,%r5   ;offset 0x12e8
        XOR     %r8,%r4,%r1     ;offset 0x12ec
        ADD     %r21,%r2,%r8    ;offset 0x12f0
        AND     %r24,%r9,%r9    ;offset 0x12f4
        AND     %r24,%r5,%r2    ;offset 0x12f8
        LDW     0(0,%r8),%r5    ;offset 0x12fc
        ADD     %r22,%r9,%r7    ;offset 0x1300
        LDW     0(0,%r7),%r7    ;offset 0x1304
        XOR     %r3,%r6,%r8     ;offset 0x1308
        ADD     %r20,%r2,%r6    ;offset 0x130c
        EXTRU   %r1,23,24,%r2   ;offset 0x1310
        XOR     %r8,%r7,%r3     ;offset 0x1314
        AND     %r24,%r2,%r8    ;offset 0x1318
        AND     %r24,%r1,%r9    ;offset 0x131c
        XOR     %r3,%r5,%r2     ;offset 0x1320
        LDW     0(0,%r6),%r6    ;offset 0x1324
        ADD     %r19,%r9,%r7    ;offset 0x1328
        EXTRU   %r1,15,16,%r1   ;offset 0x132c
        ADD     %r29,%r8,%r5    ;offset 0x1330
        LDW     0(0,%r7),%r7    ;offset 0x1334
        AND     %r24,%r1,%r3    ;offset 0x1338
        EXTRU   %r1,23,24,%r8   ;offset 0x133c
        XOR     %r2,%r6,%r1     ;offset 0x1340
        AND     %r24,%r8,%r9    ;offset 0x1344
        LDW     0(0,%r5),%r6    ;offset 0x1348
        XOR     %r1,%r7,%r8     ;offset 0x134c
        ADD     %r23,%r3,%r3    ;offset 0x1350
        LDW     0(0,%r3),%r7    ;offset 0x1354
        XOR     %r8,%r6,%r8     ;offset 0x1358
        ADD     %r31,%r9,%r3    ;offset 0x135c
        LDW     0(0,%r3),%r6    ;offset 0x1360
        LDW     52(0,%r25),%r2  ;offset 0x1364
        XOR     %r8,%r7,%r1     ;offset 0x1368
        XOR     %r1,%r6,%r1     ;offset 0x136c
        XOR     %r2,%r1,%r9     ;offset 0x1370
        ZDEP    %r9,27,28,%r8   ;offset 0x1374
        EXTRU   %r9,3,4,%r6     ;offset 0x1378
        OR      %r8,%r6,%r2     ;offset 0x137c
        EXTRU   %r2,23,24,%r7   ;offset 0x1380
        AND     %r24,%r2,%r2    ;offset 0x1384
        AND     %r24,%r7,%r8    ;offset 0x1388
        ADD     %r28,%r2,%r9    ;offset 0x138c
        LDW     0(0,%r9),%r2    ;offset 0x1390
        ADD     %r22,%r8,%r6    ;offset 0x1394
        LDW     0(0,%r6),%r9    ;offset 0x1398
        XOR     %r4,%r2,%r8     ;offset 0x139c
        XOR     %r8,%r9,%r2     ;offset 0x13a0
        LDW     48(0,%r25),%r9  ;offset 0x13a4
        EXTRU   %r7,23,24,%r3   ;offset 0x13a8
        AND     %r24,%r3,%r7    ;offset 0x13ac
        XOR     %r9,%r1,%r4     ;offset 0x13b0
        ADD     %r21,%r7,%r9    ;offset 0x13b4
        EXTRU   %r3,23,24,%r8   ;offset 0x13b8
        LDW     0(0,%r9),%r5    ;offset 0x13bc
        AND     %r24,%r8,%r7    ;offset 0x13c0
        ADD     %r20,%r7,%r9    ;offset 0x13c4
        EXTRU   %r4,23,24,%r7   ;offset 0x13c8
        AND     %r24,%r4,%r8    ;offset 0x13cc
        LDW     0(0,%r9),%r4    ;offset 0x13d0
        EXTRU   %r7,23,24,%r6   ;offset 0x13d4
        AND     %r24,%r7,%r9    ;offset 0x13d8
        XOR     %r2,%r5,%r7     ;offset 0x13dc
        AND     %r24,%r6,%r2    ;offset 0x13e0
        ADD     %r19,%r8,%r8    ;offset 0x13e4
        LDW     0(0,%r8),%r3    ;offset 0x13e8
        EXTRU   %r6,23,24,%r6   ;offset 0x13ec
        ADD     %r29,%r9,%r5    ;offset 0x13f0
        ADD     %r23,%r2,%r2    ;offset 0x13f4
        AND     %r24,%r6,%r8    ;offset 0x13f8
        LDW     0(0,%r5),%r5    ;offset 0x13fc
        LDW     0(0,%r2),%r6    ;offset 0x1400
        XOR     %r7,%r4,%r4     ;offset 0x1404
        XOR     %r4,%r3,%r7     ;offset 0x1408
        ADD     %r31,%r8,%r2    ;offset 0x140c
        XOR     %r7,%r5,%r8     ;offset 0x1410
        LDW     0(0,%r2),%r5    ;offset 0x1414
        LDW     44(0,%r25),%r4  ;offset 0x1418
        XOR     %r8,%r6,%r7     ;offset 0x141c
        XOR     %r7,%r5,%r3     ;offset 0x1420
        XOR     %r4,%r3,%r8     ;offset 0x1424
        ZDEP    %r8,27,28,%r7   ;offset 0x1428
        EXTRU   %r8,3,4,%r5     ;offset 0x142c
        OR      %r7,%r5,%r9     ;offset 0x1430
        EXTRU   %r9,23,24,%r8   ;offset 0x1434
        LDW     40(0,%r25),%r4  ;offset 0x1438
        EXTRU   %r8,23,24,%r5   ;offset 0x143c
        AND     %r24,%r9,%r9    ;offset 0x1440
        ADD     %r28,%r9,%r2    ;offset 0x1444
        AND     %r24,%r5,%r7    ;offset 0x1448
        LDW     0(0,%r2),%r2    ;offset 0x144c
        AND     %r24,%r8,%r6    ;offset 0x1450
        XOR     %r4,%r3,%r5     ;offset 0x1454
        ADD     %r21,%r7,%r7    ;offset 0x1458
        LDW     0(0,%r7),%r4    ;offset 0x145c
        EXTRU   %r8,15,16,%r8   ;offset 0x1460
        XOR     %r1,%r2,%r7     ;offset 0x1464
        AND     %r24,%r8,%r8    ;offset 0x1468
        ADD     %r22,%r6,%r6    ;offset 0x146c
        ADD     %r20,%r8,%r2    ;offset 0x1470
        LDW     0(0,%r6),%r6    ;offset 0x1474
        EXTRU   %r5,23,24,%r8   ;offset 0x1478
        AND     %r24,%r5,%r9    ;offset 0x147c
        LDW     0(0,%r2),%r5    ;offset 0x1480
        XOR     %r7,%r6,%r1     ;offset 0x1484
        ADD     %r19,%r9,%r2    ;offset 0x1488
        EXTRU   %r8,23,24,%r7   ;offset 0x148c
        AND     %r24,%r8,%r9    ;offset 0x1490
        LDW     0(0,%r2),%r6    ;offset 0x1494
        XOR     %r1,%r4,%r8     ;offset 0x1498
        ADD     %r29,%r9,%r4    ;offset 0x149c
        AND     %r24,%r7,%r1    ;offset 0x14a0
        XOR     %r8,%r5,%r5     ;offset 0x14a4
        LDW     0(0,%r4),%r4    ;offset 0x14a8
        XOR     %r5,%r6,%r6     ;offset 0x14ac
        EXTRU   %r7,23,24,%r2   ;offset 0x14b0
        ADD     %r23,%r1,%r9    ;offset 0x14b4
        LDW     0(0,%r9),%r5    ;offset 0x14b8
        AND     %r24,%r2,%r7    ;offset 0x14bc
        ADD     %r31,%r7,%r9    ;offset 0x14c0
        XOR     %r6,%r4,%r6     ;offset 0x14c4
        LDW     0(0,%r9),%r4    ;offset 0x14c8
        LDW     36(0,%r25),%r2  ;offset 0x14cc
        XOR     %r6,%r5,%r9     ;offset 0x14d0
        XOR     %r9,%r4,%r1     ;offset 0x14d4
        XOR     %r2,%r1,%r8     ;offset 0x14d8
        ZDEP    %r8,27,28,%r6   ;offset 0x14dc
        EXTRU   %r8,3,4,%r4     ;offset 0x14e0
        OR      %r6,%r4,%r8     ;offset 0x14e4
        EXTRU   %r8,23,24,%r7   ;offset 0x14e8
        AND     %r24,%r8,%r8    ;offset 0x14ec
        AND     %r24,%r7,%r2    ;offset 0x14f0
        ADD     %r28,%r8,%r9    ;offset 0x14f4
        EXTRU   %r7,23,24,%r8   ;offset 0x14f8
        ADD     %r22,%r2,%r4    ;offset 0x14fc
        LDW     0(0,%r9),%r7    ;offset 0x1500
        LDW     32(0,%r25),%r6  ;offset 0x1504
        AND     %r24,%r8,%r2    ;offset 0x1508
        LDW     0(0,%r4),%r5    ;offset 0x150c
        EXTRU   %r8,23,24,%r8   ;offset 0x1510
        XOR     %r6,%r1,%r4     ;offset 0x1514
        AND     %r24,%r8,%r9    ;offset 0x1518
        XOR     %r3,%r7,%r3     ;offset 0x151c
        XOR     %r3,%r5,%r7     ;offset 0x1520
        ADD     %r20,%r9,%r8    ;offset 0x1524
        ADD     %r21,%r2,%r6    ;offset 0x1528
        LDW     0(0,%r6),%r2    ;offset 0x152c
        LDW     0(0,%r8),%r3    ;offset 0x1530
        AND     %r24,%r4,%r9    ;offset 0x1534
        EXTRU   %r4,23,24,%r6   ;offset 0x1538
        EXTRU   %r4,15,16,%r5   ;offset 0x153c
        ADD     %r19,%r9,%r8    ;offset 0x1540
        LDW     0(0,%r8),%r4    ;offset 0x1544
        XOR     %r7,%r2,%r2     ;offset 0x1548
        AND     %r24,%r6,%r6    ;offset 0x154c
        ADD     %r29,%r6,%r8    ;offset 0x1550
        XOR     %r2,%r3,%r3     ;offset 0x1554
        LDW     0(0,%r8),%r2    ;offset 0x1558
        AND     %r24,%r5,%r6    ;offset 0x155c
        ADD     %r23,%r6,%r8    ;offset 0x1560
        XOR     %r3,%r4,%r6     ;offset 0x1564
        EXTRU   %r5,23,24,%r7   ;offset 0x1568
        LDW     0(0,%r8),%r4    ;offset 0x156c
        AND     %r24,%r7,%r5    ;offset 0x1570
        ADD     %r31,%r5,%r8    ;offset 0x1574
        XOR     %r6,%r2,%r7     ;offset 0x1578
        LDW     0(0,%r8),%r2    ;offset 0x157c
        LDW     28(0,%r25),%r5  ;offset 0x1580
        XOR     %r7,%r4,%r6     ;offset 0x1584
        XOR     %r6,%r2,%r3     ;offset 0x1588
        XOR     %r5,%r3,%r6     ;offset 0x158c
        ZDEP    %r6,27,28,%r5   ;offset 0x1590
        EXTRU   %r6,3,4,%r2     ;offset 0x1594
        OR      %r5,%r2,%r6     ;offset 0x1598
        EXTRU   %r6,23,24,%r5   ;offset 0x159c
        EXTRU   %r5,23,24,%r7   ;offset 0x15a0
        AND     %r24,%r5,%r9    ;offset 0x15a4
        AND     %r24,%r6,%r6    ;offset 0x15a8
        LDW     24(0,%r25),%r8  ;offset 0x15ac
        AND     %r24,%r7,%r4    ;offset 0x15b0
        ADD     %r28,%r6,%r6    ;offset 0x15b4
        ADD     %r22,%r9,%r2    ;offset 0x15b8
        LDW     0(0,%r2),%r7    ;offset 0x15bc
        LDW     0(0,%r6),%r6    ;offset 0x15c0
        EXTRU   %r5,15,16,%r5   ;offset 0x15c4
        XOR     %r8,%r3,%r2     ;offset 0x15c8
        ADD     %r21,%r4,%r4    ;offset 0x15cc
        LDW     0(0,%r4),%r4    ;offset 0x15d0
        AND     %r24,%r5,%r8    ;offset 0x15d4
        XOR     %r1,%r6,%r6     ;offset 0x15d8
        ADD     %r20,%r8,%r9    ;offset 0x15dc
        AND     %r24,%r2,%r5    ;offset 0x15e0
        XOR     %r6,%r7,%r6     ;offset 0x15e4
        LDW     0(0,%r9),%r1    ;offset 0x15e8
        ADD     %r19,%r5,%r5    ;offset 0x15ec
        XOR     %r6,%r4,%r6     ;offset 0x15f0
        LDW     0(0,%r5),%r4    ;offset 0x15f4
        XOR     %r6,%r1,%r5     ;offset 0x15f8
        XOR     %r5,%r4,%r1     ;offset 0x15fc
        EXTRU   %r2,23,24,%r4   ;offset 0x1600
        EXTRU   %r2,15,16,%r2   ;offset 0x1604
        AND     %r24,%r4,%r4    ;offset 0x1608
        AND     %r24,%r2,%r6    ;offset 0x160c
        EXTRU   %r2,23,24,%r7   ;offset 0x1610
        ADD     %r23,%r6,%r2    ;offset 0x1614
        ADD     %r29,%r4,%r4    ;offset 0x1618
        LDW     0(0,%r4),%r5    ;offset 0x161c
        AND     %r24,%r7,%r6    ;offset 0x1620
        LDW     0(0,%r2),%r8    ;offset 0x1624
        ADD     %r31,%r6,%r9    ;offset 0x1628
        XOR     %r1,%r5,%r6     ;offset 0x162c
        LDW     0(0,%r9),%r7    ;offset 0x1630
        XOR     %r6,%r8,%r8     ;offset 0x1634
        LDW     20(0,%r25),%r6  ;offset 0x1638
        XOR     %r8,%r7,%r2     ;offset 0x163c
        XOR     %r6,%r2,%r7     ;offset 0x1640
        ZDEP    %r7,27,28,%r4   ;offset 0x1644
        EXTRU   %r7,3,4,%r1     ;offset 0x1648
        OR      %r4,%r1,%r5     ;offset 0x164c
        EXTRU   %r5,23,24,%r4   ;offset 0x1650
        AND     %r24,%r5,%r1    ;offset 0x1654
        ADD     %r28,%r1,%r5    ;offset 0x1658
        AND     %r24,%r4,%r7    ;offset 0x165c
        LDW     16(0,%r25),%r1  ;offset 0x1660
        EXTRU   %r4,23,24,%r6   ;offset 0x1664
        ADD     %r22,%r7,%r9    ;offset 0x1668
        AND     %r24,%r6,%r7    ;offset 0x166c
        XOR     %r1,%r2,%r6     ;offset 0x1670
        LDW     0(0,%r5),%r5    ;offset 0x1674
        EXTRU   %r4,15,16,%r8   ;offset 0x1678
        ADD     %r21,%r7,%r1    ;offset 0x167c
        LDW     0(0,%r9),%r4    ;offset 0x1680
        AND     %r24,%r8,%r7    ;offset 0x1684
        XOR     %r3,%r5,%r8     ;offset 0x1688
        LDW     0(0,%r1),%r1    ;offset 0x168c
        XOR     %r8,%r4,%r5     ;offset 0x1690
        ADD     %r20,%r7,%r7    ;offset 0x1694
        LDW     0(0,%r7),%r7    ;offset 0x1698
        AND     %r24,%r6,%r9    ;offset 0x169c
        EXTRU   %r6,15,16,%r8   ;offset 0x16a0
        EXTRU   %r6,23,24,%r3   ;offset 0x16a4
        AND     %r24,%r3,%r6    ;offset 0x16a8
        XOR     %r5,%r1,%r1     ;offset 0x16ac
        ADD     %r19,%r9,%r4    ;offset 0x16b0
        LDW     0(0,%r4),%r3    ;offset 0x16b4
        ADD     %r29,%r6,%r6    ;offset 0x16b8
        XOR     %r1,%r7,%r7     ;offset 0x16bc
        LDW     0(0,%r6),%r1    ;offset 0x16c0
        AND     %r24,%r8,%r4    ;offset 0x16c4
        EXTRU   %r8,23,24,%r5   ;offset 0x16c8
        ADD     %r23,%r4,%r6    ;offset 0x16cc
        AND     %r24,%r5,%r4    ;offset 0x16d0
        XOR     %r7,%r3,%r5     ;offset 0x16d4
        LDW     0(0,%r6),%r3    ;offset 0x16d8
        XOR     %r5,%r1,%r6     ;offset 0x16dc
        ADD     %r31,%r4,%r7    ;offset 0x16e0
        LDW     0(0,%r7),%r1    ;offset 0x16e4
        LDW     12(0,%r25),%r7  ;offset 0x16e8
        XOR     %r6,%r3,%r5     ;offset 0x16ec
        XOR     %r5,%r1,%r1     ;offset 0x16f0
        XOR     %r7,%r1,%r4     ;offset 0x16f4
        ZDEP    %r4,27,28,%r3   ;offset 0x16f8
        EXTRU   %r4,3,4,%r9     ;offset 0x16fc
        OR      %r3,%r9,%r4     ;offset 0x1700
        EXTRU   %r4,23,24,%r6   ;offset 0x1704
        AND     %r24,%r4,%r9    ;offset 0x1708
        ADD     %r28,%r9,%r7    ;offset 0x170c
        AND     %r24,%r6,%r5    ;offset 0x1710
        LDW     0(0,%r7),%r3    ;offset 0x1714
        ADD     %r22,%r5,%r5    ;offset 0x1718
        LDW     0(0,%r5),%r5    ;offset 0x171c
        XOR     %r2,%r3,%r3     ;offset 0x1720
        EXTRU   %r4,15,16,%r4   ;offset 0x1724
        XOR     %r3,%r5,%r3     ;offset 0x1728
        LDW     8(0,%r25),%r9   ;offset 0x172c
        EXTRU   %r4,23,24,%r5   ;offset 0x1730
        AND     %r24,%r4,%r6    ;offset 0x1734
        AND     %r24,%r5,%r5    ;offset 0x1738
        XOR     %r9,%r1,%r4     ;offset 0x173c
        ADD     %r21,%r6,%r2    ;offset 0x1740
        ADD     %r20,%r5,%r7    ;offset 0x1744
        LDW     0(0,%r2),%r6    ;offset 0x1748
        LDW     0(0,%r7),%r5    ;offset 0x174c
        AND     %r24,%r4,%r8    ;offset 0x1750
        EXTRU   %r4,23,24,%r7   ;offset 0x1754
        ADD     %r19,%r8,%r9    ;offset 0x1758
        EXTRU   %r7,23,24,%r8   ;offset 0x175c
        XOR     %r3,%r6,%r3     ;offset 0x1760
        LDW     0(0,%r9),%r4    ;offset 0x1764
        AND     %r24,%r8,%r6    ;offset 0x1768
        AND     %r24,%r7,%r7    ;offset 0x176c
        XOR     %r3,%r5,%r3     ;offset 0x1770
        ADD     %r29,%r7,%r9    ;offset 0x1774
        EXTRU   %r8,23,24,%r8   ;offset 0x1778
        LDW     0(0,%r9),%r7    ;offset 0x177c
        ADD     %r23,%r6,%r6    ;offset 0x1780
        AND     %r24,%r8,%r5    ;offset 0x1784
        LDW     0(0,%r6),%r6    ;offset 0x1788
        XOR     %r3,%r4,%r9     ;offset 0x178c
        ADD     %r31,%r5,%r5    ;offset 0x1790
        LDW     0(0,%r5),%r8    ;offset 0x1794
        XOR     %r9,%r7,%r9     ;offset 0x1798
        LDW     4(0,%r25),%r2   ;offset 0x179c
        LDW     0(0,%r25),%r3   ;offset 0x17a0
        XOR     %r9,%r6,%r7     ;offset 0x17a4
        XOR     %r7,%r8,%r25    ;offset 0x17a8
        XOR     %r2,%r25,%r4    ;offset 0x17ac
        ZDEP    %r4,27,28,%r2   ;offset 0x17b0
        EXTRU   %r4,3,4,%r8     ;offset 0x17b4
        OR      %r2,%r8,%r6     ;offset 0x17b8
        EXTRU   %r6,23,24,%r9   ;offset 0x17bc
        AND     %r24,%r6,%r2    ;offset 0x17c0
        ADD     %r28,%r2,%r5    ;offset 0x17c4
        LDW     0(0,%r5),%r7    ;offset 0x17c8
        EXTRU   %r6,15,16,%r8   ;offset 0x17cc
        AND     %r24,%r9,%r9    ;offset 0x17d0
        ADD     %r22,%r9,%r6    ;offset 0x17d4
        LDW     0(0,%r6),%r22   ;offset 0x17d8
        AND     %r24,%r8,%r6    ;offset 0x17dc
        ADD     %r21,%r6,%r9    ;offset 0x17e0
        LDW     0(0,%r9),%r5    ;offset 0x17e4
        EXTRU   %r8,23,24,%r8   ;offset 0x17e8
        AND     %r24,%r8,%r4    ;offset 0x17ec
        ADD     %r20,%r4,%r8    ;offset 0x17f0
        LDW     0(0,%r8),%r6    ;offset 0x17f4
        XOR     %r3,%r25,%r9    ;offset 0x17f8
        XOR     %r1,%r7,%r21    ;offset 0x17fc
        AND     %r24,%r9,%r7    ;offset 0x1800
        ADD     %r19,%r7,%r28   ;offset 0x1804
        LDW     0(0,%r28),%r7   ;offset 0x1808
        EXTRU   %r9,23,24,%r20  ;offset 0x180c
        EXTRU   %r9,15,16,%r8   ;offset 0x1810
        AND     %r24,%r20,%r19  ;offset 0x1814
        ADD     %r29,%r19,%r4   ;offset 0x1818
        LDW     0(0,%r4),%r29   ;offset 0x181c
        XOR     %r21,%r22,%r3   ;offset 0x1820
        AND     %r24,%r8,%r2    ;offset 0x1824
        ADD     %r23,%r2,%r9    ;offset 0x1828
        LDW     0(0,%r9),%r9    ;offset 0x182c
        EXTRU   %r8,23,24,%r1   ;offset 0x1830
        XOR     %r3,%r5,%r3     ;offset 0x1834
        AND     %r24,%r1,%r24   ;offset 0x1838
        ADD     %r31,%r24,%r22  ;offset 0x183c
        LDW     0(0,%r22),%r8   ;offset 0x1840
        XOR     %r3,%r6,%r23    ;offset 0x1844
        XOR     %r23,%r7,%r31   ;offset 0x1848
        XOR     %r31,%r29,%r2   ;offset 0x184c
        XOR     %r2,%r9,%r4     ;offset 0x1850
        XOR     %r4,%r8,%r7     ;offset 0x1854
        ZDEP    %r25,30,31,%r20 ;offset 0x1858
        EXTRU   %r25,0,1,%r5    ;offset 0x185c
        OR      %r20,%r5,%r6    ;offset 0x1860
        STBS    %r6,4(0,%r26)   ;offset 0x1864
        EXTRU   %r6,23,24,%r9   ;offset 0x1868
        STBS    %r9,5(0,%r26)   ;offset 0x186c
        EXTRU   %r6,15,16,%r8   ;offset 0x1870
        STBS    %r8,6(0,%r26)   ;offset 0x1874
        EXTRU   %r6,7,8,%r23    ;offset 0x1878
        STBS    %r23,7(0,%r26)  ;offset 0x187c
        ZDEP    %r7,30,31,%r3   ;offset 0x1880
        EXTRU   %r7,0,1,%r31    ;offset 0x1884
        OR      %r3,%r31,%r24   ;offset 0x1888
        STBS    %r24,0(0,%r26)  ;offset 0x188c
        EXTRU   %r24,23,24,%r29 ;offset 0x1890
        STBS    %r29,1(0,%r26)  ;offset 0x1894
        EXTRU   %r24,15,16,%r25 ;offset 0x1898
        STBS    %r25,2(0,%r26)  ;offset 0x189c
        EXTRU   %r24,7,8,%r19   ;offset 0x18a0
        STBS    %r19,3(0,%r26)  ;offset 0x18a4
        LDW     -84(0,%r30),%r2 ;offset 0x18a8
        LDW     -40(0,%r30),%r9 ;offset 0x18ac
        LDW     -44(0,%r30),%r8 ;offset 0x18b0
        LDW     -48(0,%r30),%r7 ;offset 0x18b4
        LDW     -52(0,%r30),%r6 ;offset 0x18b8
        LDW     -56(0,%r30),%r5 ;offset 0x18bc
        LDW     -60(0,%r30),%r4 ;offset 0x18c0
        BV      %r0(%r2)        ;offset 0x18c4
        .EXIT
        LDWM    -64(0,%r30),%r3 ;offset 0x18c8
        .PROCEND ;in=24,25,26;


        .SPACE  $TEXT$
        .SUBSPA $CODE$
        .SUBSPA $CODE$
        .SPACE  $PRIVATE$,SORT=16
        .SUBSPA $DATA$,QUAD=1,ALIGN=8,ACCESS=31,SORT=16
DS$desSmallCore
        .ALIGN  8
        .STRINGZ "$Id: desCore.h,v 1.10 1992/04/16 23:08:44 how E $"
        .BLOCK  2
        .BLOCK  4
        .STRINGZ "$Id: desCode.h,v 1.16 1992/04/17 00:44:43 how E $"
        .BLOCK  2
        .IMPORT $global$,DATA
        .SPACE  $TEXT$
        .SUBSPA $CODE$
        .EXPORT DesSmallCoreEncrypt,ENTRY,PRIV_LEV=3,ARGW0=GR,ARGW1=GR,ARGW2=GR
        .IMPORT des_keymap,DATA
        .SUBSPA $CODE$
        .EXPORT DesSmallCoreDecrypt,ENTRY,PRIV_LEV=3,ARGW0=GR,ARGW1=GR,ARGW2=GR
        .END
