
        .SPACE  $TEXT$,SORT=8
        .SUBSPA $CODE$,QUAD=0,ALIGN=8,ACCESS=44,CODE_ONLY,SORT=24
DesQuickFipsEncrypt
        .PROC
        .CALLINFO CALLER,FRAME=0,ENTRY_GR=7,ENTRY_SR=3,SAVE_RP
        .ENTRY
        STW     %r2,-20(0,%r30) ;offset 0x0
        STWM    %r3,64(0,%r30)  ;offset 0x4
        STW     %r4,-60(0,%r30) ;offset 0x8
        STW     %r5,-56(0,%r30) ;offset 0xc
        STW     %r6,-52(0,%r30) ;offset 0x10
        STW     %r7,-48(0,%r30) ;offset 0x14
        LDIL    LR'+252641280,%r28      ;offset 0x18
        LDB     7(0,%r24),%r23  ;offset 0x1c
        LDB     6(0,%r24),%r4   ;offset 0x20
        LDB     3(0,%r24),%r31  ;offset 0x24
        LDB     2(0,%r24),%r5   ;offset 0x28
        ZDEP    %r23,23,24,%r6  ;offset 0x2c
        OR      %r6,%r4,%r6     ;offset 0x30
        ZDEP    %r31,23,24,%r29 ;offset 0x34
        LDB     5(0,%r24),%r4   ;offset 0x38
        OR      %r29,%r5,%r23   ;offset 0x3c
        ZDEP    %r6,23,24,%r5   ;offset 0x40
        LDB     1(0,%r24),%r6   ;offset 0x44
        OR      %r5,%r4,%r7     ;offset 0x48
        LDB     4(0,%r24),%r31  ;offset 0x4c
        ZDEP    %r7,23,24,%r21  ;offset 0x50
        ZDEP    %r23,23,24,%r23 ;offset 0x54
        LDB     0(0,%r24),%r7   ;offset 0x58
        OR      %r23,%r6,%r29   ;offset 0x5c
        OR      %r21,%r31,%r19  ;offset 0x60
        ZDEP    %r29,23,24,%r4  ;offset 0x64
        OR      %r4,%r7,%r3     ;offset 0x68
        EXTRU   %r19,27,28,%r24 ;offset 0x6c
        XOR     %r24,%r3,%r22   ;offset 0x70
        LDO     RR'+252645135(%r28),%r31        ;offset 0x74
        AND     %r22,%r31,%r1   ;offset 0x78
        XOR     %r3,%r1,%r7     ;offset 0x7c
        ZDEP    %r1,27,28,%r20  ;offset 0x80
        XOR     %r19,%r20,%r5   ;offset 0x84
        EXTRU   %r7,15,16,%r21  ;offset 0x88
        XOR     %r21,%r5,%r22   ;offset 0x8c
        EXTRU   %r22,31,16,%r2  ;offset 0x90
        XOR     %r5,%r2,%r3     ;offset 0x94
        ZDEP    %r22,15,16,%r28 ;offset 0x98
        XOR     %r7,%r28,%r2    ;offset 0x9c
        EXTRU   %r3,29,30,%r20  ;offset 0xa0
        LDIL    LR'+858996736,%r19      ;offset 0xa4
        XOR     %r20,%r2,%r29   ;offset 0xa8
        LDO     RR'+858993459(%r19),%r23        ;offset 0xac
        AND     %r29,%r23,%r20  ;offset 0xb0
        XOR     %r2,%r20,%r29   ;offset 0xb4
        ZDEP    %r20,29,30,%r4  ;offset 0xb8
        XOR     %r3,%r4,%r3     ;offset 0xbc
        EXTRU   %r29,23,24,%r24 ;offset 0xc0
        LDIL    LR'+16711680,%r2        ;offset 0xc4
        XOR     %r24,%r3,%r1    ;offset 0xc8
        LDO     RR'+16711935(%r2),%r24  ;offset 0xcc
        AND     %r1,%r24,%r5    ;offset 0xd0
        XOR     %r3,%r5,%r20    ;offset 0xd4
        EXTRU   %r20,30,31,%r19 ;offset 0xd8
        ZDEP    %r5,23,24,%r1   ;offset 0xdc
        ZDEP    %r20,0,1,%r20   ;offset 0xe0
        OR      %r19,%r20,%r22  ;offset 0xe4
        XOR     %r29,%r1,%r4    ;offset 0xe8
        LDIL    LR'+1431658496,%r28     ;offset 0xec
        XOR     %r22,%r4,%r21   ;offset 0xf0
        LDO     RR'+1431655765(%r28),%r29       ;offset 0xf4
        AND     %r21,%r29,%r28  ;offset 0xf8
        XOR     %r4,%r28,%r6    ;offset 0xfc
        EXTRU   %r6,30,31,%r21  ;offset 0x100
        ZDEP    %r6,0,1,%r1     ;offset 0x104
        OR      %r21,%r1,%r3    ;offset 0x108
        LDW     0(0,%r25),%r20  ;offset 0x10c
        LDIL    LR'+65536,%r1   ;offset 0x110
        LDO     RR'+64764(%r1),%r19     ;offset 0x114
        ADDIL   LR'des_bigmap-$global$,%r27     ;offset 0x118
        XOR     %r20,%r3,%r7    ;offset 0x11c
        LDO     RR'des_bigmap-$global$(%r1),%r20        ;offset 0x120
        AND     %r19,%r7,%r6    ;offset 0x124
        EXTRU   %r7,15,16,%r21  ;offset 0x128
        ADD     %r20,%r6,%r6    ;offset 0x12c
        AND     %r19,%r21,%r2   ;offset 0x130
        LDW     0(0,%r6),%r4    ;offset 0x134
        LDO     RR'des_bigmap-$global$+256(%r1),%r21    ;offset 0x138
        LDW     4(0,%r25),%r5   ;offset 0x13c
        ADD     %r21,%r2,%r6    ;offset 0x140
        LDW     0(0,%r6),%r2    ;offset 0x144
        XOR     %r22,%r28,%r22  ;offset 0x148
        XOR     %r22,%r4,%r6    ;offset 0x14c
        XOR     %r5,%r3,%r5     ;offset 0x150
        ZDEP    %r5,27,28,%r4   ;offset 0x154
        EXTRU   %r5,3,4,%r5     ;offset 0x158
        OR      %r4,%r5,%r4     ;offset 0x15c
        AND     %r19,%r4,%r28   ;offset 0x160
        XOR     %r6,%r2,%r2     ;offset 0x164
        LDO     RR'des_bigmap-$global$+512(%r1),%r22    ;offset 0x168
        EXTRU   %r4,15,16,%r4   ;offset 0x16c
        ADD     %r22,%r28,%r6   ;offset 0x170
        LDO     RR'des_bigmap-$global$+768(%r1),%r28    ;offset 0x174
        AND     %r19,%r4,%r4    ;offset 0x178
        LDW     0(0,%r6),%r1    ;offset 0x17c
        ADD     %r28,%r4,%r4    ;offset 0x180
        LDW     0(0,%r4),%r5    ;offset 0x184
        LDW     8(0,%r25),%r6   ;offset 0x188
        XOR     %r2,%r1,%r7     ;offset 0x18c
        XOR     %r7,%r5,%r1     ;offset 0x190
        LDW     12(0,%r25),%r4  ;offset 0x194
        XOR     %r6,%r1,%r2     ;offset 0x198
        AND     %r19,%r2,%r5    ;offset 0x19c
        XOR     %r4,%r1,%r4     ;offset 0x1a0
        EXTRU   %r2,15,16,%r2   ;offset 0x1a4
        ADD     %r20,%r5,%r7    ;offset 0x1a8
        ZDEP    %r4,27,28,%r6   ;offset 0x1ac
        AND     %r19,%r2,%r5    ;offset 0x1b0
        LDW     0(0,%r7),%r2    ;offset 0x1b4
        EXTRU   %r4,3,4,%r4     ;offset 0x1b8
        OR      %r6,%r4,%r4     ;offset 0x1bc
        ADD     %r21,%r5,%r7    ;offset 0x1c0
        AND     %r19,%r4,%r6    ;offset 0x1c4
        EXTRU   %r4,15,16,%r5   ;offset 0x1c8
        LDW     0(0,%r7),%r4    ;offset 0x1cc
        ADD     %r22,%r6,%r7    ;offset 0x1d0
        AND     %r19,%r5,%r6    ;offset 0x1d4
        LDW     0(0,%r7),%r5    ;offset 0x1d8
        XOR     %r3,%r2,%r2     ;offset 0x1dc
        XOR     %r2,%r4,%r2     ;offset 0x1e0
        ADD     %r28,%r6,%r3    ;offset 0x1e4
        LDW     0(0,%r3),%r4    ;offset 0x1e8
        XOR     %r2,%r5,%r2     ;offset 0x1ec
        LDW     20(0,%r25),%r5  ;offset 0x1f0
        LDW     16(0,%r25),%r7  ;offset 0x1f4
        XOR     %r2,%r4,%r3     ;offset 0x1f8
        XOR     %r5,%r3,%r5     ;offset 0x1fc
        ZDEP    %r5,27,28,%r2   ;offset 0x200
        EXTRU   %r5,3,4,%r6     ;offset 0x204
        XOR     %r7,%r3,%r4     ;offset 0x208
        AND     %r19,%r4,%r5    ;offset 0x20c
        EXTRU   %r4,15,16,%r4   ;offset 0x210
        OR      %r2,%r6,%r2     ;offset 0x214
        ADD     %r20,%r5,%r6    ;offset 0x218
        AND     %r19,%r4,%r7    ;offset 0x21c
        LDW     0(0,%r6),%r4    ;offset 0x220
        AND     %r19,%r2,%r5    ;offset 0x224
        EXTRU   %r2,15,16,%r6   ;offset 0x228
        ADD     %r21,%r7,%r7    ;offset 0x22c
        LDW     0(0,%r7),%r2    ;offset 0x230
        ADD     %r22,%r5,%r5    ;offset 0x234
        AND     %r19,%r6,%r6    ;offset 0x238
        LDW     0(0,%r5),%r5    ;offset 0x23c
        XOR     %r1,%r4,%r4     ;offset 0x240
        ADD     %r28,%r6,%r7    ;offset 0x244
        LDW     0(0,%r7),%r1    ;offset 0x248
        XOR     %r4,%r2,%r4     ;offset 0x24c
        XOR     %r4,%r5,%r7     ;offset 0x250
        LDW     24(0,%r25),%r4  ;offset 0x254
        XOR     %r7,%r1,%r2     ;offset 0x258
        XOR     %r4,%r2,%r4     ;offset 0x25c
        AND     %r19,%r4,%r7    ;offset 0x260
        EXTRU   %r4,15,16,%r1   ;offset 0x264
        ADD     %r20,%r7,%r7    ;offset 0x268
        LDW     0(0,%r7),%r5    ;offset 0x26c
        AND     %r19,%r1,%r6    ;offset 0x270
        ADD     %r21,%r6,%r6    ;offset 0x274
        LDW     0(0,%r6),%r1    ;offset 0x278
        XOR     %r3,%r5,%r3     ;offset 0x27c
        LDW     28(0,%r25),%r5  ;offset 0x280
        XOR     %r3,%r1,%r4     ;offset 0x284
        XOR     %r5,%r2,%r1     ;offset 0x288
        ZDEP    %r1,27,28,%r7   ;offset 0x28c
        EXTRU   %r1,3,4,%r1     ;offset 0x290
        OR      %r7,%r1,%r6     ;offset 0x294
        AND     %r19,%r6,%r5    ;offset 0x298
        EXTRU   %r6,15,16,%r6   ;offset 0x29c
        ADD     %r22,%r5,%r5    ;offset 0x2a0
        LDW     0(0,%r5),%r7    ;offset 0x2a4
        AND     %r19,%r6,%r3    ;offset 0x2a8
        ADD     %r28,%r3,%r3    ;offset 0x2ac
        LDW     0(0,%r3),%r3    ;offset 0x2b0
        XOR     %r4,%r7,%r7     ;offset 0x2b4
        LDW     32(0,%r25),%r4  ;offset 0x2b8
        LDW     36(0,%r25),%r6  ;offset 0x2bc
        XOR     %r7,%r3,%r1     ;offset 0x2c0
        XOR     %r4,%r1,%r3     ;offset 0x2c4
        XOR     %r6,%r1,%r4     ;offset 0x2c8
        ZDEP    %r4,27,28,%r5   ;offset 0x2cc
        EXTRU   %r4,3,4,%r4     ;offset 0x2d0
        AND     %r19,%r3,%r6    ;offset 0x2d4
        OR      %r5,%r4,%r4     ;offset 0x2d8
        EXTRU   %r3,15,16,%r3   ;offset 0x2dc
        ADD     %r20,%r6,%r5    ;offset 0x2e0
        AND     %r19,%r3,%r6    ;offset 0x2e4
        LDW     0(0,%r5),%r3    ;offset 0x2e8
        ADD     %r21,%r6,%r7    ;offset 0x2ec
        AND     %r19,%r4,%r6    ;offset 0x2f0
        EXTRU   %r4,15,16,%r5   ;offset 0x2f4
        LDW     0(0,%r7),%r4    ;offset 0x2f8
        ADD     %r22,%r6,%r7    ;offset 0x2fc
        AND     %r19,%r5,%r6    ;offset 0x300
        LDW     0(0,%r7),%r5    ;offset 0x304
        XOR     %r2,%r3,%r3     ;offset 0x308
        ADD     %r28,%r6,%r6    ;offset 0x30c
        LDW     0(0,%r6),%r2    ;offset 0x310
        XOR     %r3,%r4,%r3     ;offset 0x314
        LDW     44(0,%r25),%r7  ;offset 0x318
        XOR     %r3,%r5,%r6     ;offset 0x31c
        LDW     40(0,%r25),%r5  ;offset 0x320
        XOR     %r6,%r2,%r3     ;offset 0x324
        XOR     %r7,%r3,%r6     ;offset 0x328
        ZDEP    %r6,27,28,%r4   ;offset 0x32c
        EXTRU   %r6,3,4,%r2     ;offset 0x330
        XOR     %r5,%r3,%r5     ;offset 0x334
        AND     %r19,%r5,%r6    ;offset 0x338
        OR      %r4,%r2,%r2     ;offset 0x33c
        EXTRU   %r5,15,16,%r5   ;offset 0x340
        ADD     %r20,%r6,%r4    ;offset 0x344
        AND     %r19,%r5,%r5    ;offset 0x348
        LDW     0(0,%r4),%r4    ;offset 0x34c
        ADD     %r21,%r5,%r7    ;offset 0x350
        AND     %r19,%r2,%r5    ;offset 0x354
        EXTRU   %r2,15,16,%r6   ;offset 0x358
        LDW     0(0,%r7),%r2    ;offset 0x35c
        XOR     %r1,%r4,%r1     ;offset 0x360
        ADD     %r22,%r5,%r5    ;offset 0x364
        AND     %r19,%r6,%r6    ;offset 0x368
        LDW     0(0,%r5),%r5    ;offset 0x36c
        ADD     %r28,%r6,%r4    ;offset 0x370
        LDW     0(0,%r4),%r7    ;offset 0x374
        XOR     %r1,%r2,%r1     ;offset 0x378
        LDW     48(0,%r25),%r6  ;offset 0x37c
        XOR     %r1,%r5,%r2     ;offset 0x380
        XOR     %r2,%r7,%r1     ;offset 0x384
        XOR     %r6,%r1,%r4     ;offset 0x388
        AND     %r19,%r4,%r2    ;offset 0x38c
        ADD     %r20,%r2,%r5    ;offset 0x390
        LDW     0(0,%r5),%r2    ;offset 0x394
        LDW     52(0,%r25),%r5  ;offset 0x398
        EXTRU   %r4,15,16,%r4   ;offset 0x39c
        XOR     %r5,%r1,%r6     ;offset 0x3a0
        ZDEP    %r6,27,28,%r5   ;offset 0x3a4
        EXTRU   %r6,3,4,%r7     ;offset 0x3a8
        OR      %r5,%r7,%r5     ;offset 0x3ac
        AND     %r19,%r5,%r6    ;offset 0x3b0
        AND     %r19,%r4,%r4    ;offset 0x3b4
        ADD     %r21,%r4,%r4    ;offset 0x3b8
        EXTRU   %r5,15,16,%r5   ;offset 0x3bc
        ADD     %r22,%r6,%r7    ;offset 0x3c0
        LDW     0(0,%r4),%r4    ;offset 0x3c4
        AND     %r19,%r5,%r6    ;offset 0x3c8
        LDW     0(0,%r7),%r5    ;offset 0x3cc
        XOR     %r3,%r2,%r2     ;offset 0x3d0
        XOR     %r2,%r4,%r7     ;offset 0x3d4
        ADD     %r28,%r6,%r3    ;offset 0x3d8
        LDW     0(0,%r3),%r6    ;offset 0x3dc
        XOR     %r7,%r5,%r4     ;offset 0x3e0
        LDW     56(0,%r25),%r7  ;offset 0x3e4
        LDW     60(0,%r25),%r2  ;offset 0x3e8
        XOR     %r4,%r6,%r3     ;offset 0x3ec
        XOR     %r7,%r3,%r4     ;offset 0x3f0
        XOR     %r2,%r3,%r5     ;offset 0x3f4
        ZDEP    %r5,27,28,%r2   ;offset 0x3f8
        EXTRU   %r5,3,4,%r7     ;offset 0x3fc
        AND     %r19,%r4,%r5    ;offset 0x400
        EXTRU   %r4,15,16,%r6   ;offset 0x404
        OR      %r2,%r7,%r4     ;offset 0x408
        ADD     %r20,%r5,%r2    ;offset 0x40c
        AND     %r19,%r6,%r7    ;offset 0x410
        EXTRU   %r4,15,16,%r6   ;offset 0x414
        ADD     %r21,%r7,%r7    ;offset 0x418
        AND     %r19,%r4,%r5    ;offset 0x41c
        LDW     0(0,%r7),%r4    ;offset 0x420
        LDW     0(0,%r2),%r2    ;offset 0x424
        ADD     %r22,%r5,%r7    ;offset 0x428
        LDW     0(0,%r7),%r5    ;offset 0x42c
        XOR     %r1,%r2,%r7     ;offset 0x430
        AND     %r19,%r6,%r6    ;offset 0x434
        ADD     %r28,%r6,%r2    ;offset 0x438
        XOR     %r7,%r4,%r6     ;offset 0x43c
        LDW     0(0,%r2),%r4    ;offset 0x440
        XOR     %r6,%r5,%r5     ;offset 0x444
        LDW     64(0,%r25),%r1  ;offset 0x448
        LDW     68(0,%r25),%r6  ;offset 0x44c
        XOR     %r5,%r4,%r4     ;offset 0x450
        XOR     %r6,%r4,%r2     ;offset 0x454
        XOR     %r1,%r4,%r5     ;offset 0x458
        ZDEP    %r2,27,28,%r1   ;offset 0x45c
        EXTRU   %r2,3,4,%r7     ;offset 0x460
        AND     %r19,%r5,%r6    ;offset 0x464
        OR      %r1,%r7,%r2     ;offset 0x468
        ADD     %r20,%r6,%r7    ;offset 0x46c
        EXTRU   %r5,15,16,%r5   ;offset 0x470
        LDW     0(0,%r7),%r1    ;offset 0x474
        AND     %r19,%r5,%r6    ;offset 0x478
        ADD     %r21,%r6,%r7    ;offset 0x47c
        AND     %r19,%r2,%r5    ;offset 0x480
        EXTRU   %r2,15,16,%r6   ;offset 0x484
        LDW     0(0,%r7),%r2    ;offset 0x488
        XOR     %r3,%r1,%r7     ;offset 0x48c
        AND     %r19,%r6,%r6    ;offset 0x490
        ADD     %r22,%r5,%r5    ;offset 0x494
        ADD     %r28,%r6,%r1    ;offset 0x498
        LDW     0(0,%r5),%r5    ;offset 0x49c
        XOR     %r7,%r2,%r6     ;offset 0x4a0
        LDW     0(0,%r1),%r7    ;offset 0x4a4
        XOR     %r6,%r5,%r5     ;offset 0x4a8
        XOR     %r5,%r7,%r1     ;offset 0x4ac
        LDW     72(0,%r25),%r5  ;offset 0x4b0
        LDW     76(0,%r25),%r3  ;offset 0x4b4
        XOR     %r5,%r1,%r7     ;offset 0x4b8
        EXTRU   %r7,15,16,%r5   ;offset 0x4bc
        XOR     %r3,%r1,%r6     ;offset 0x4c0
        AND     %r19,%r7,%r2    ;offset 0x4c4
        ZDEP    %r6,27,28,%r7   ;offset 0x4c8
        EXTRU   %r6,3,4,%r6     ;offset 0x4cc
        OR      %r7,%r6,%r3     ;offset 0x4d0
        ADD     %r20,%r2,%r6    ;offset 0x4d4
        AND     %r19,%r5,%r5    ;offset 0x4d8
        LDW     0(0,%r6),%r2    ;offset 0x4dc
        ADD     %r21,%r5,%r7    ;offset 0x4e0
        EXTRU   %r3,15,16,%r6   ;offset 0x4e4
        AND     %r19,%r3,%r5    ;offset 0x4e8
        LDW     0(0,%r7),%r3    ;offset 0x4ec
        ADD     %r22,%r5,%r7    ;offset 0x4f0
        LDW     0(0,%r7),%r5    ;offset 0x4f4
        AND     %r19,%r6,%r6    ;offset 0x4f8
        XOR     %r4,%r2,%r2     ;offset 0x4fc
        XOR     %r2,%r3,%r3     ;offset 0x500
        ADD     %r28,%r6,%r7    ;offset 0x504
        LDW     0(0,%r7),%r2    ;offset 0x508
        XOR     %r3,%r5,%r4     ;offset 0x50c
        LDW     80(0,%r25),%r3  ;offset 0x510
        LDW     84(0,%r25),%r7  ;offset 0x514
        XOR     %r4,%r2,%r2     ;offset 0x518
        XOR     %r7,%r2,%r7     ;offset 0x51c
        XOR     %r3,%r2,%r3     ;offset 0x520
        ZDEP    %r7,27,28,%r5   ;offset 0x524
        EXTRU   %r7,3,4,%r4     ;offset 0x528
        AND     %r19,%r3,%r6    ;offset 0x52c
        EXTRU   %r3,15,16,%r3   ;offset 0x530
        OR      %r5,%r4,%r4     ;offset 0x534
        ADD     %r20,%r6,%r5    ;offset 0x538
        AND     %r19,%r3,%r7    ;offset 0x53c
        LDW     0(0,%r5),%r3    ;offset 0x540
        AND     %r19,%r4,%r5    ;offset 0x544
        EXTRU   %r4,15,16,%r6   ;offset 0x548
        ADD     %r21,%r7,%r7    ;offset 0x54c
        LDW     0(0,%r7),%r4    ;offset 0x550
        ADD     %r22,%r5,%r5    ;offset 0x554
        AND     %r19,%r6,%r6    ;offset 0x558
        LDW     0(0,%r5),%r5    ;offset 0x55c
        XOR     %r1,%r3,%r3     ;offset 0x560
        ADD     %r28,%r6,%r6    ;offset 0x564
        LDW     0(0,%r6),%r1    ;offset 0x568
        XOR     %r3,%r4,%r3     ;offset 0x56c
        LDW     92(0,%r25),%r4  ;offset 0x570
        XOR     %r3,%r5,%r3     ;offset 0x574
        LDW     88(0,%r25),%r5  ;offset 0x578
        XOR     %r3,%r1,%r1     ;offset 0x57c
        XOR     %r4,%r1,%r7     ;offset 0x580
        XOR     %r5,%r1,%r3     ;offset 0x584
        ZDEP    %r7,27,28,%r4   ;offset 0x588
        EXTRU   %r3,15,16,%r6   ;offset 0x58c
        EXTRU   %r7,3,4,%r7     ;offset 0x590
        AND     %r19,%r3,%r5    ;offset 0x594
        OR      %r4,%r7,%r3     ;offset 0x598
        ADD     %r20,%r5,%r4    ;offset 0x59c
        AND     %r19,%r6,%r6    ;offset 0x5a0
        LDW     0(0,%r4),%r4    ;offset 0x5a4
        ADD     %r21,%r6,%r5    ;offset 0x5a8
        AND     %r19,%r3,%r7    ;offset 0x5ac
        LDW     0(0,%r5),%r5    ;offset 0x5b0
        ADD     %r22,%r7,%r6    ;offset 0x5b4
        LDW     0(0,%r6),%r6    ;offset 0x5b8
        XOR     %r2,%r4,%r2     ;offset 0x5bc
        XOR     %r2,%r5,%r7     ;offset 0x5c0
        EXTRU   %r3,15,16,%r3   ;offset 0x5c4
        XOR     %r7,%r6,%r2     ;offset 0x5c8
        AND     %r19,%r3,%r3    ;offset 0x5cc
        ADD     %r28,%r3,%r6    ;offset 0x5d0
        LDW     0(0,%r6),%r3    ;offset 0x5d4
        LDW     96(0,%r25),%r6  ;offset 0x5d8
        LDW     100(0,%r25),%r5 ;offset 0x5dc
        XOR     %r2,%r3,%r3     ;offset 0x5e0
        XOR     %r6,%r3,%r6     ;offset 0x5e4
        XOR     %r5,%r3,%r4     ;offset 0x5e8
        AND     %r19,%r6,%r5    ;offset 0x5ec
        EXTRU   %r6,15,16,%r2   ;offset 0x5f0
        ADD     %r20,%r5,%r7    ;offset 0x5f4
        ZDEP    %r4,27,28,%r6   ;offset 0x5f8
        AND     %r19,%r2,%r5    ;offset 0x5fc
        LDW     0(0,%r7),%r2    ;offset 0x600
        EXTRU   %r4,3,4,%r4     ;offset 0x604
        OR      %r6,%r4,%r4     ;offset 0x608
        ADD     %r21,%r5,%r7    ;offset 0x60c
        EXTRU   %r4,15,16,%r6   ;offset 0x610
        AND     %r19,%r4,%r5    ;offset 0x614
        LDW     0(0,%r7),%r4    ;offset 0x618
        XOR     %r1,%r2,%r1     ;offset 0x61c
        ADD     %r22,%r5,%r7    ;offset 0x620
        AND     %r19,%r6,%r6    ;offset 0x624
        LDW     0(0,%r7),%r5    ;offset 0x628
        ADD     %r28,%r6,%r2    ;offset 0x62c
        LDW     0(0,%r2),%r6    ;offset 0x630
        XOR     %r1,%r4,%r7     ;offset 0x634
        XOR     %r7,%r5,%r2     ;offset 0x638
        LDW     104(0,%r25),%r1 ;offset 0x63c
        LDW     108(0,%r25),%r7 ;offset 0x640
        XOR     %r2,%r6,%r4     ;offset 0x644
        XOR     %r7,%r4,%r6     ;offset 0x648
        XOR     %r1,%r4,%r5     ;offset 0x64c
        ZDEP    %r6,27,28,%r1   ;offset 0x650
        EXTRU   %r6,3,4,%r2     ;offset 0x654
        AND     %r19,%r5,%r6    ;offset 0x658
        OR      %r1,%r2,%r2     ;offset 0x65c
        EXTRU   %r5,15,16,%r5   ;offset 0x660
        ADD     %r20,%r6,%r6    ;offset 0x664
        LDW     0(0,%r6),%r1    ;offset 0x668
        AND     %r19,%r5,%r7    ;offset 0x66c
        AND     %r19,%r2,%r5    ;offset 0x670
        EXTRU   %r2,15,16,%r6   ;offset 0x674
        ADD     %r21,%r7,%r7    ;offset 0x678
        LDW     0(0,%r7),%r2    ;offset 0x67c
        XOR     %r3,%r1,%r7     ;offset 0x680
        ADD     %r22,%r5,%r5    ;offset 0x684
        AND     %r19,%r6,%r6    ;offset 0x688
        LDW     0(0,%r5),%r5    ;offset 0x68c
        ADD     %r28,%r6,%r1    ;offset 0x690
        LDW     0(0,%r1),%r6    ;offset 0x694
        XOR     %r7,%r2,%r2     ;offset 0x698
        LDW     112(0,%r25),%r7 ;offset 0x69c
        XOR     %r2,%r5,%r1     ;offset 0x6a0
        XOR     %r1,%r6,%r1     ;offset 0x6a4
        XOR     %r7,%r1,%r6     ;offset 0x6a8
        AND     %r19,%r6,%r2    ;offset 0x6ac
        EXTRU   %r6,15,16,%r3   ;offset 0x6b0
        AND     %r19,%r3,%r7    ;offset 0x6b4
        ADD     %r20,%r2,%r5    ;offset 0x6b8
        LDW     0(0,%r5),%r2    ;offset 0x6bc
        LDW     116(0,%r25),%r3 ;offset 0x6c0
        ADD     %r21,%r7,%r5    ;offset 0x6c4
        LDW     0(0,%r5),%r5    ;offset 0x6c8
        XOR     %r3,%r1,%r3     ;offset 0x6cc
        XOR     %r4,%r2,%r2     ;offset 0x6d0
        ZDEP    %r3,27,28,%r7   ;offset 0x6d4
        EXTRU   %r3,3,4,%r6     ;offset 0x6d8
        OR      %r7,%r6,%r3     ;offset 0x6dc
        XOR     %r2,%r5,%r2     ;offset 0x6e0
        AND     %r19,%r3,%r5    ;offset 0x6e4
        EXTRU   %r3,15,16,%r6   ;offset 0x6e8
        ADD     %r22,%r5,%r7    ;offset 0x6ec
        LDW     0(0,%r7),%r3    ;offset 0x6f0
        AND     %r19,%r6,%r4    ;offset 0x6f4
        ADD     %r28,%r4,%r5    ;offset 0x6f8
        LDW     0(0,%r5),%r6    ;offset 0x6fc
        XOR     %r2,%r3,%r7     ;offset 0x700
        LDW     124(0,%r25),%r3 ;offset 0x704
        LDW     120(0,%r25),%r2 ;offset 0x708
        XOR     %r7,%r6,%r4     ;offset 0x70c
        XOR     %r3,%r4,%r5     ;offset 0x710
        XOR     %r2,%r4,%r2     ;offset 0x714
        AND     %r19,%r2,%r25   ;offset 0x718
        EXTRU   %r2,15,16,%r3   ;offset 0x71c
        ZDEP    %r5,27,28,%r6   ;offset 0x720
        EXTRU   %r5,3,4,%r7     ;offset 0x724
        OR      %r6,%r7,%r2     ;offset 0x728
        AND     %r19,%r3,%r7    ;offset 0x72c
        ADD     %r20,%r25,%r25  ;offset 0x730
        ADD     %r21,%r7,%r5    ;offset 0x734
        AND     %r19,%r2,%r3    ;offset 0x738
        EXTRU   %r2,15,16,%r6   ;offset 0x73c
        LDW     0(0,%r25),%r25  ;offset 0x740
        ADD     %r22,%r3,%r22   ;offset 0x744
        AND     %r19,%r6,%r21   ;offset 0x748
        LDW     0(0,%r5),%r5    ;offset 0x74c
        LDW     0(0,%r22),%r19  ;offset 0x750
        ADD     %r28,%r21,%r22  ;offset 0x754
        XOR     %r1,%r25,%r2    ;offset 0x758
        LDW     0(0,%r22),%r20  ;offset 0x75c
        XOR     %r2,%r5,%r28    ;offset 0x760
        XOR     %r28,%r19,%r7   ;offset 0x764
        ZDEP    %r4,30,31,%r21  ;offset 0x768
        EXTRU   %r4,0,1,%r2     ;offset 0x76c
        XOR     %r7,%r20,%r7    ;offset 0x770
        OR      %r21,%r2,%r3    ;offset 0x774
        XOR     %r3,%r7,%r28    ;offset 0x778
        AND     %r28,%r29,%r21  ;offset 0x77c
        XOR     %r7,%r21,%r19   ;offset 0x780
        XOR     %r3,%r21,%r25   ;offset 0x784
        ZDEP    %r19,30,31,%r22 ;offset 0x788
        EXTRU   %r19,0,1,%r5    ;offset 0x78c
        OR      %r22,%r5,%r4    ;offset 0x790
        EXTRU   %r25,23,24,%r6  ;offset 0x794
        XOR     %r6,%r4,%r7     ;offset 0x798
        AND     %r7,%r24,%r3    ;offset 0x79c
        XOR     %r4,%r3,%r24    ;offset 0x7a0
        ZDEP    %r3,23,24,%r1   ;offset 0x7a4
        XOR     %r25,%r1,%r6    ;offset 0x7a8
        EXTRU   %r24,29,30,%r2  ;offset 0x7ac
        XOR     %r2,%r6,%r3     ;offset 0x7b0
        AND     %r3,%r23,%r29   ;offset 0x7b4
        XOR     %r6,%r29,%r25   ;offset 0x7b8
        ZDEP    %r29,29,30,%r6  ;offset 0x7bc
        XOR     %r24,%r6,%r2    ;offset 0x7c0
        EXTRU   %r25,15,16,%r7  ;offset 0x7c4
        XOR     %r7,%r2,%r23    ;offset 0x7c8
        EXTRU   %r23,31,16,%r19 ;offset 0x7cc
        XOR     %r2,%r19,%r29   ;offset 0x7d0
        ZDEP    %r23,15,16,%r5  ;offset 0x7d4
        XOR     %r25,%r5,%r3    ;offset 0x7d8
        EXTRU   %r29,27,28,%r24 ;offset 0x7dc
        XOR     %r24,%r3,%r25   ;offset 0x7e0
        AND     %r25,%r31,%r1   ;offset 0x7e4
        XOR     %r3,%r1,%r19    ;offset 0x7e8
        STBS    %r19,0(0,%r26)  ;offset 0x7ec
        EXTRU   %r19,23,24,%r20 ;offset 0x7f0
        STBS    %r20,1(0,%r26)  ;offset 0x7f4
        EXTRU   %r19,15,16,%r3  ;offset 0x7f8
        STBS    %r3,2(0,%r26)   ;offset 0x7fc
        ZDEP    %r1,27,28,%r21  ;offset 0x800
        XOR     %r29,%r21,%r28  ;offset 0x804
        STBS    %r28,4(0,%r26)  ;offset 0x808
        EXTRU   %r28,23,24,%r22 ;offset 0x80c
        STBS    %r22,5(0,%r26)  ;offset 0x810
        EXTRU   %r28,15,16,%r29 ;offset 0x814
        STBS    %r29,6(0,%r26)  ;offset 0x818
        EXTRU   %r19,7,8,%r1    ;offset 0x81c
        STBS    %r1,3(0,%r26)   ;offset 0x820
        EXTRU   %r28,7,8,%r2    ;offset 0x824
        STBS    %r2,7(0,%r26)   ;offset 0x828
        LDW     -84(0,%r30),%r2 ;offset 0x82c
        LDW     -48(0,%r30),%r7 ;offset 0x830
        LDW     -52(0,%r30),%r6 ;offset 0x834
        LDW     -56(0,%r30),%r5 ;offset 0x838
        LDW     -60(0,%r30),%r4 ;offset 0x83c
        BV      %r0(%r2)        ;offset 0x840
        .EXIT
        LDWM    -64(0,%r30),%r3 ;offset 0x844
        .PROCEND ;in=24,25,26;


        .SPACE  $TEXT$
        .SUBSPA $CODE$,QUAD=0,ALIGN=8,ACCESS=44,CODE_ONLY,SORT=24
DesQuickFipsDecrypt
        .PROC
        .CALLINFO CALLER,FRAME=0,ENTRY_GR=7,ENTRY_SR=3,SAVE_RP
        .ENTRY
        STW     %r2,-20(0,%r30) ;offset 0x848
        STWM    %r3,64(0,%r30)  ;offset 0x84c
        STW     %r4,-60(0,%r30) ;offset 0x850
        STW     %r5,-56(0,%r30) ;offset 0x854
        STW     %r6,-52(0,%r30) ;offset 0x858
        STW     %r7,-48(0,%r30) ;offset 0x85c
        LDIL    LR'+252641280,%r22      ;offset 0x860
        LDB     7(0,%r24),%r7   ;offset 0x864
        LDB     6(0,%r24),%r4   ;offset 0x868
        LDB     3(0,%r24),%r23  ;offset 0x86c
        ZDEP    %r7,23,24,%r5   ;offset 0x870
        LDB     2(0,%r24),%r6   ;offset 0x874
        OR      %r5,%r4,%r7     ;offset 0x878
        ZDEP    %r7,23,24,%r4   ;offset 0x87c
        ZDEP    %r23,23,24,%r31 ;offset 0x880
        LDB     5(0,%r24),%r5   ;offset 0x884
        LDB     1(0,%r24),%r7   ;offset 0x888
        OR      %r31,%r6,%r29   ;offset 0x88c
        ZDEP    %r29,23,24,%r6  ;offset 0x890
        LDB     4(0,%r24),%r29  ;offset 0x894
        OR      %r6,%r7,%r19    ;offset 0x898
        OR      %r4,%r5,%r31    ;offset 0x89c
        LDB     0(0,%r24),%r7   ;offset 0x8a0
        ZDEP    %r31,23,24,%r20 ;offset 0x8a4
        OR      %r20,%r29,%r5   ;offset 0x8a8
        ZDEP    %r19,23,24,%r2  ;offset 0x8ac
        OR      %r2,%r7,%r2     ;offset 0x8b0
        EXTRU   %r5,27,28,%r31  ;offset 0x8b4
        XOR     %r31,%r2,%r21   ;offset 0x8b8
        LDO     RR'+252645135(%r22),%r31        ;offset 0x8bc
        AND     %r21,%r31,%r28  ;offset 0x8c0
        XOR     %r2,%r28,%r3    ;offset 0x8c4
        ZDEP    %r28,27,28,%r29 ;offset 0x8c8
        XOR     %r5,%r29,%r5    ;offset 0x8cc
        EXTRU   %r3,15,16,%r19  ;offset 0x8d0
        XOR     %r19,%r5,%r20   ;offset 0x8d4
        EXTRU   %r20,31,16,%r1  ;offset 0x8d8
        XOR     %r5,%r1,%r24    ;offset 0x8dc
        ZDEP    %r20,15,16,%r21 ;offset 0x8e0
        XOR     %r3,%r21,%r3    ;offset 0x8e4
        EXTRU   %r24,29,30,%r23 ;offset 0x8e8
        LDIL    LR'+858996736,%r19      ;offset 0x8ec
        XOR     %r23,%r3,%r29   ;offset 0x8f0
        LDO     RR'+858993459(%r19),%r23        ;offset 0x8f4
        AND     %r29,%r23,%r20  ;offset 0x8f8
        XOR     %r3,%r20,%r29   ;offset 0x8fc
        ZDEP    %r20,29,30,%r3  ;offset 0x900
        XOR     %r24,%r3,%r5    ;offset 0x904
        EXTRU   %r29,23,24,%r24 ;offset 0x908
        LDIL    LR'+16711680,%r2        ;offset 0x90c
        XOR     %r24,%r5,%r1    ;offset 0x910
        LDO     RR'+16711935(%r2),%r24  ;offset 0x914
        AND     %r1,%r24,%r7    ;offset 0x918
        XOR     %r5,%r7,%r22    ;offset 0x91c
        ZDEP    %r7,23,24,%r28  ;offset 0x920
        XOR     %r29,%r28,%r6   ;offset 0x924
        EXTRU   %r22,30,31,%r21 ;offset 0x928
        ZDEP    %r22,0,1,%r19   ;offset 0x92c
        OR      %r21,%r19,%r4   ;offset 0x930
        LDIL    LR'+1431658496,%r28     ;offset 0x934
        XOR     %r4,%r6,%r20    ;offset 0x938
        LDO     RR'+1431655765(%r28),%r29       ;offset 0x93c
        AND     %r20,%r29,%r22  ;offset 0x940
        XOR     %r6,%r22,%r19   ;offset 0x944
        LDW     124(0,%r25),%r5 ;offset 0x948
        EXTRU   %r19,30,31,%r1  ;offset 0x94c
        ZDEP    %r19,0,1,%r2    ;offset 0x950
        OR      %r1,%r2,%r3     ;offset 0x954
        XOR     %r5,%r3,%r28    ;offset 0x958
        ZDEP    %r28,27,28,%r6  ;offset 0x95c
        EXTRU   %r28,3,4,%r28   ;offset 0x960
        LDIL    LR'+65536,%r19  ;offset 0x964
        OR      %r6,%r28,%r7    ;offset 0x968
        LDO     RR'+64764(%r19),%r19    ;offset 0x96c
        ADDIL   LR'des_bigmap-$global$,%r27     ;offset 0x970
        AND     %r19,%r7,%r6    ;offset 0x974
        EXTRU   %r7,15,16,%r21  ;offset 0x978
        LDO     RR'des_bigmap-$global$+512(%r1),%r20    ;offset 0x97c
        AND     %r19,%r21,%r7   ;offset 0x980
        ADD     %r20,%r6,%r5    ;offset 0x984
        LDO     RR'des_bigmap-$global$+768(%r1),%r21    ;offset 0x988
        LDW     0(0,%r5),%r28   ;offset 0x98c
        XOR     %r4,%r22,%r6    ;offset 0x990
        ADD     %r21,%r7,%r2    ;offset 0x994
        LDW     0(0,%r2),%r5    ;offset 0x998
        LDW     120(0,%r25),%r4 ;offset 0x99c
        XOR     %r6,%r28,%r6    ;offset 0x9a0
        XOR     %r4,%r3,%r4     ;offset 0x9a4
        XOR     %r6,%r5,%r2     ;offset 0x9a8
        EXTRU   %r4,15,16,%r5   ;offset 0x9ac
        LDO     RR'des_bigmap-$global$(%r1),%r22        ;offset 0x9b0
        AND     %r19,%r4,%r28   ;offset 0x9b4
        ADD     %r22,%r28,%r4   ;offset 0x9b8
        AND     %r19,%r5,%r6    ;offset 0x9bc
        LDW     0(0,%r4),%r5    ;offset 0x9c0
        LDO     RR'des_bigmap-$global$+256(%r1),%r28    ;offset 0x9c4
        ADD     %r28,%r6,%r4    ;offset 0x9c8
        LDW     0(0,%r4),%r1    ;offset 0x9cc
        LDW     116(0,%r25),%r7 ;offset 0x9d0
        XOR     %r2,%r5,%r4     ;offset 0x9d4
        XOR     %r4,%r1,%r1     ;offset 0x9d8
        XOR     %r7,%r1,%r4     ;offset 0x9dc
        ZDEP    %r4,27,28,%r2   ;offset 0x9e0
        EXTRU   %r4,3,4,%r5     ;offset 0x9e4
        LDW     112(0,%r25),%r7 ;offset 0x9e8
        OR      %r2,%r5,%r6     ;offset 0x9ec
        AND     %r19,%r6,%r4    ;offset 0x9f0
        XOR     %r7,%r1,%r2     ;offset 0x9f4
        EXTRU   %r6,15,16,%r6   ;offset 0x9f8
        AND     %r19,%r6,%r7    ;offset 0x9fc
        ADD     %r20,%r4,%r4    ;offset 0xa00
        LDW     0(0,%r4),%r4    ;offset 0xa04
        EXTRU   %r2,15,16,%r6   ;offset 0xa08
        ADD     %r21,%r7,%r7    ;offset 0xa0c
        AND     %r19,%r2,%r5    ;offset 0xa10
        LDW     0(0,%r7),%r2    ;offset 0xa14
        ADD     %r22,%r5,%r7    ;offset 0xa18
        AND     %r19,%r6,%r6    ;offset 0xa1c
        XOR     %r3,%r4,%r3     ;offset 0xa20
        LDW     0(0,%r7),%r5    ;offset 0xa24
        ADD     %r28,%r6,%r4    ;offset 0xa28
        LDW     0(0,%r4),%r7    ;offset 0xa2c
        XOR     %r3,%r2,%r6     ;offset 0xa30
        LDW     108(0,%r25),%r3 ;offset 0xa34
        XOR     %r6,%r5,%r2     ;offset 0xa38
        XOR     %r2,%r7,%r2     ;offset 0xa3c
        XOR     %r3,%r2,%r3     ;offset 0xa40
        ZDEP    %r3,27,28,%r7   ;offset 0xa44
        EXTRU   %r3,3,4,%r4     ;offset 0xa48
        OR      %r7,%r4,%r5     ;offset 0xa4c
        AND     %r19,%r5,%r3    ;offset 0xa50
        LDW     104(0,%r25),%r4 ;offset 0xa54
        EXTRU   %r5,15,16,%r5   ;offset 0xa58
        ADD     %r20,%r3,%r7    ;offset 0xa5c
        LDW     0(0,%r7),%r3    ;offset 0xa60
        AND     %r19,%r5,%r6    ;offset 0xa64
        XOR     %r4,%r2,%r4     ;offset 0xa68
        ADD     %r21,%r6,%r7    ;offset 0xa6c
        AND     %r19,%r4,%r5    ;offset 0xa70
        EXTRU   %r4,15,16,%r6   ;offset 0xa74
        LDW     0(0,%r7),%r4    ;offset 0xa78
        XOR     %r1,%r3,%r3     ;offset 0xa7c
        ADD     %r22,%r5,%r5    ;offset 0xa80
        AND     %r19,%r6,%r6    ;offset 0xa84
        LDW     0(0,%r5),%r5    ;offset 0xa88
        ADD     %r28,%r6,%r1    ;offset 0xa8c
        LDW     0(0,%r1),%r6    ;offset 0xa90
        XOR     %r3,%r4,%r3     ;offset 0xa94
        LDW     100(0,%r25),%r4 ;offset 0xa98
        XOR     %r3,%r5,%r3     ;offset 0xa9c
        XOR     %r3,%r6,%r1     ;offset 0xaa0
        XOR     %r4,%r1,%r7     ;offset 0xaa4
        ZDEP    %r7,27,28,%r6   ;offset 0xaa8
        EXTRU   %r7,3,4,%r3     ;offset 0xaac
        OR      %r6,%r3,%r3     ;offset 0xab0
        AND     %r19,%r3,%r7    ;offset 0xab4
        ADD     %r20,%r7,%r4    ;offset 0xab8
        LDW     0(0,%r4),%r7    ;offset 0xabc
        LDW     96(0,%r25),%r4  ;offset 0xac0
        EXTRU   %r3,15,16,%r3   ;offset 0xac4
        XOR     %r2,%r7,%r2     ;offset 0xac8
        AND     %r19,%r3,%r7    ;offset 0xacc
        XOR     %r4,%r1,%r3     ;offset 0xad0
        ADD     %r21,%r7,%r5    ;offset 0xad4
        AND     %r19,%r3,%r7    ;offset 0xad8
        EXTRU   %r3,15,16,%r4   ;offset 0xadc
        LDW     0(0,%r5),%r3    ;offset 0xae0
        AND     %r19,%r4,%r5    ;offset 0xae4
        ADD     %r22,%r7,%r6    ;offset 0xae8
        LDW     0(0,%r6),%r4    ;offset 0xaec
        ADD     %r28,%r5,%r5    ;offset 0xaf0
        LDW     0(0,%r5),%r5    ;offset 0xaf4
        XOR     %r2,%r3,%r2     ;offset 0xaf8
        LDW     92(0,%r25),%r6  ;offset 0xafc
        XOR     %r2,%r4,%r7     ;offset 0xb00
        XOR     %r7,%r5,%r3     ;offset 0xb04
        XOR     %r6,%r3,%r6     ;offset 0xb08
        ZDEP    %r6,27,28,%r5   ;offset 0xb0c
        EXTRU   %r6,3,4,%r2     ;offset 0xb10
        OR      %r5,%r2,%r7     ;offset 0xb14
        LDW     88(0,%r25),%r5  ;offset 0xb18
        AND     %r19,%r7,%r6    ;offset 0xb1c
        EXTRU   %r7,15,16,%r7   ;offset 0xb20
        ADD     %r20,%r6,%r6    ;offset 0xb24
        LDW     0(0,%r6),%r4    ;offset 0xb28
        XOR     %r5,%r3,%r2     ;offset 0xb2c
        AND     %r19,%r7,%r7    ;offset 0xb30
        EXTRU   %r2,15,16,%r6   ;offset 0xb34
        ADD     %r21,%r7,%r7    ;offset 0xb38
        AND     %r19,%r2,%r5    ;offset 0xb3c
        LDW     0(0,%r7),%r2    ;offset 0xb40
        ADD     %r22,%r5,%r7    ;offset 0xb44
        LDW     0(0,%r7),%r5    ;offset 0xb48
        AND     %r19,%r6,%r6    ;offset 0xb4c
        XOR     %r1,%r4,%r1     ;offset 0xb50
        ADD     %r28,%r6,%r7    ;offset 0xb54
        LDW     0(0,%r7),%r4    ;offset 0xb58
        XOR     %r1,%r2,%r1     ;offset 0xb5c
        LDW     84(0,%r25),%r7  ;offset 0xb60
        XOR     %r1,%r5,%r1     ;offset 0xb64
        XOR     %r1,%r4,%r1     ;offset 0xb68
        XOR     %r7,%r1,%r5     ;offset 0xb6c
        ZDEP    %r5,27,28,%r4   ;offset 0xb70
        EXTRU   %r5,3,4,%r7     ;offset 0xb74
        OR      %r4,%r7,%r6     ;offset 0xb78
        LDW     80(0,%r25),%r7  ;offset 0xb7c
        AND     %r19,%r6,%r5    ;offset 0xb80
        EXTRU   %r6,15,16,%r6   ;offset 0xb84
        XOR     %r7,%r1,%r4     ;offset 0xb88
        ADD     %r20,%r5,%r5    ;offset 0xb8c
        AND     %r19,%r6,%r6    ;offset 0xb90
        LDW     0(0,%r5),%r2    ;offset 0xb94
        ADD     %r21,%r6,%r7    ;offset 0xb98
        AND     %r19,%r4,%r5    ;offset 0xb9c
        EXTRU   %r4,15,16,%r6   ;offset 0xba0
        LDW     0(0,%r7),%r4    ;offset 0xba4
        ADD     %r22,%r5,%r5    ;offset 0xba8
        LDW     0(0,%r5),%r5    ;offset 0xbac
        XOR     %r3,%r2,%r7     ;offset 0xbb0
        AND     %r19,%r6,%r6    ;offset 0xbb4
        ADD     %r28,%r6,%r6    ;offset 0xbb8
        XOR     %r7,%r4,%r4     ;offset 0xbbc
        LDW     0(0,%r6),%r2    ;offset 0xbc0
        XOR     %r4,%r5,%r5     ;offset 0xbc4
        LDW     76(0,%r25),%r4  ;offset 0xbc8
        XOR     %r5,%r2,%r3     ;offset 0xbcc
        XOR     %r4,%r3,%r4     ;offset 0xbd0
        ZDEP    %r4,27,28,%r2   ;offset 0xbd4
        EXTRU   %r4,3,4,%r6     ;offset 0xbd8
        OR      %r2,%r6,%r5     ;offset 0xbdc
        AND     %r19,%r5,%r4    ;offset 0xbe0
        LDW     72(0,%r25),%r2  ;offset 0xbe4
        EXTRU   %r5,15,16,%r5   ;offset 0xbe8
        AND     %r19,%r5,%r5    ;offset 0xbec
        XOR     %r2,%r3,%r2     ;offset 0xbf0
        ADD     %r21,%r5,%r7    ;offset 0xbf4
        EXTRU   %r2,15,16,%r6   ;offset 0xbf8
        AND     %r19,%r2,%r5    ;offset 0xbfc
        LDW     0(0,%r7),%r2    ;offset 0xc00
        ADD     %r20,%r4,%r4    ;offset 0xc04
        LDW     0(0,%r4),%r4    ;offset 0xc08
        ADD     %r22,%r5,%r7    ;offset 0xc0c
        LDW     0(0,%r7),%r5    ;offset 0xc10
        AND     %r19,%r6,%r6    ;offset 0xc14
        XOR     %r1,%r4,%r7     ;offset 0xc18
        ADD     %r28,%r6,%r4    ;offset 0xc1c
        XOR     %r7,%r2,%r6     ;offset 0xc20
        LDW     0(0,%r4),%r1    ;offset 0xc24
        XOR     %r6,%r5,%r6     ;offset 0xc28
        LDW     68(0,%r25),%r5  ;offset 0xc2c
        XOR     %r6,%r1,%r1     ;offset 0xc30
        XOR     %r5,%r1,%r2     ;offset 0xc34
        ZDEP    %r2,27,28,%r7   ;offset 0xc38
        EXTRU   %r2,3,4,%r5     ;offset 0xc3c
        OR      %r7,%r5,%r5     ;offset 0xc40
        LDW     64(0,%r25),%r4  ;offset 0xc44
        AND     %r19,%r5,%r2    ;offset 0xc48
        EXTRU   %r5,15,16,%r7   ;offset 0xc4c
        ADD     %r20,%r2,%r2    ;offset 0xc50
        LDW     0(0,%r2),%r2    ;offset 0xc54
        XOR     %r4,%r1,%r4     ;offset 0xc58
        AND     %r19,%r7,%r7    ;offset 0xc5c
        AND     %r19,%r4,%r5    ;offset 0xc60
        EXTRU   %r4,15,16,%r6   ;offset 0xc64
        ADD     %r21,%r7,%r7    ;offset 0xc68
        LDW     0(0,%r7),%r4    ;offset 0xc6c
        XOR     %r3,%r2,%r3     ;offset 0xc70
        ADD     %r22,%r5,%r5    ;offset 0xc74
        AND     %r19,%r6,%r6    ;offset 0xc78
        LDW     0(0,%r5),%r5    ;offset 0xc7c
        ADD     %r28,%r6,%r2    ;offset 0xc80
        LDW     0(0,%r2),%r7    ;offset 0xc84
        XOR     %r3,%r4,%r3     ;offset 0xc88
        LDW     60(0,%r25),%r6  ;offset 0xc8c
        XOR     %r3,%r5,%r3     ;offset 0xc90
        XOR     %r3,%r7,%r3     ;offset 0xc94
        XOR     %r6,%r3,%r7     ;offset 0xc98
        ZDEP    %r7,27,28,%r6   ;offset 0xc9c
        EXTRU   %r7,3,4,%r4     ;offset 0xca0
        OR      %r6,%r4,%r2     ;offset 0xca4
        AND     %r19,%r2,%r7    ;offset 0xca8
        LDW     56(0,%r25),%r5  ;offset 0xcac
        EXTRU   %r2,15,16,%r6   ;offset 0xcb0
        ADD     %r20,%r7,%r7    ;offset 0xcb4
        LDW     0(0,%r7),%r4    ;offset 0xcb8
        AND     %r19,%r6,%r6    ;offset 0xcbc
        XOR     %r5,%r3,%r2     ;offset 0xcc0
        ADD     %r21,%r6,%r7    ;offset 0xcc4
        EXTRU   %r2,15,16,%r6   ;offset 0xcc8
        AND     %r19,%r2,%r5    ;offset 0xccc
        LDW     0(0,%r7),%r2    ;offset 0xcd0
        ADD     %r22,%r5,%r7    ;offset 0xcd4
        LDW     0(0,%r7),%r5    ;offset 0xcd8
        AND     %r19,%r6,%r6    ;offset 0xcdc
        XOR     %r1,%r4,%r4     ;offset 0xce0
        ADD     %r28,%r6,%r7    ;offset 0xce4
        LDW     0(0,%r7),%r6    ;offset 0xce8
        XOR     %r4,%r2,%r2     ;offset 0xcec
        XOR     %r2,%r5,%r7     ;offset 0xcf0
        LDW     52(0,%r25),%r5  ;offset 0xcf4
        XOR     %r7,%r6,%r1     ;offset 0xcf8
        XOR     %r5,%r1,%r2     ;offset 0xcfc
        ZDEP    %r2,27,28,%r6   ;offset 0xd00
        EXTRU   %r2,3,4,%r2     ;offset 0xd04
        OR      %r6,%r2,%r5     ;offset 0xd08
        AND     %r19,%r5,%r6    ;offset 0xd0c
        LDW     48(0,%r25),%r4  ;offset 0xd10
        EXTRU   %r5,15,16,%r5   ;offset 0xd14
        ADD     %r20,%r6,%r6    ;offset 0xd18
        AND     %r19,%r5,%r5    ;offset 0xd1c
        LDW     0(0,%r6),%r2    ;offset 0xd20
        XOR     %r4,%r1,%r4     ;offset 0xd24
        ADD     %r21,%r5,%r7    ;offset 0xd28
        AND     %r19,%r4,%r5    ;offset 0xd2c
        EXTRU   %r4,15,16,%r6   ;offset 0xd30
        LDW     0(0,%r7),%r4    ;offset 0xd34
        ADD     %r22,%r5,%r5    ;offset 0xd38
        AND     %r19,%r6,%r6    ;offset 0xd3c
        LDW     0(0,%r5),%r5    ;offset 0xd40
        XOR     %r3,%r2,%r2     ;offset 0xd44
        ADD     %r28,%r6,%r6    ;offset 0xd48
        LDW     0(0,%r6),%r6    ;offset 0xd4c
        XOR     %r2,%r4,%r2     ;offset 0xd50
        LDW     44(0,%r25),%r7  ;offset 0xd54
        XOR     %r2,%r5,%r2     ;offset 0xd58
        XOR     %r2,%r6,%r3     ;offset 0xd5c
        XOR     %r7,%r3,%r6     ;offset 0xd60
        ZDEP    %r6,27,28,%r5   ;offset 0xd64
        EXTRU   %r6,3,4,%r2     ;offset 0xd68
        OR      %r5,%r2,%r7     ;offset 0xd6c
        LDW     40(0,%r25),%r6  ;offset 0xd70
        AND     %r19,%r7,%r5    ;offset 0xd74
        EXTRU   %r7,15,16,%r4   ;offset 0xd78
        AND     %r19,%r4,%r7    ;offset 0xd7c
        ADD     %r20,%r5,%r5    ;offset 0xd80
        LDW     0(0,%r5),%r4    ;offset 0xd84
        XOR     %r6,%r3,%r2     ;offset 0xd88
        EXTRU   %r2,15,16,%r6   ;offset 0xd8c
        ADD     %r21,%r7,%r7    ;offset 0xd90
        AND     %r19,%r2,%r5    ;offset 0xd94
        LDW     0(0,%r7),%r2    ;offset 0xd98
        XOR     %r1,%r4,%r1     ;offset 0xd9c
        ADD     %r22,%r5,%r7    ;offset 0xda0
        AND     %r19,%r6,%r6    ;offset 0xda4
        LDW     0(0,%r7),%r5    ;offset 0xda8
        ADD     %r28,%r6,%r4    ;offset 0xdac
        LDW     0(0,%r4),%r4    ;offset 0xdb0
        XOR     %r1,%r2,%r1     ;offset 0xdb4
        LDW     36(0,%r25),%r2  ;offset 0xdb8
        XOR     %r1,%r5,%r5     ;offset 0xdbc
        XOR     %r5,%r4,%r1     ;offset 0xdc0
        XOR     %r2,%r1,%r6     ;offset 0xdc4
        ZDEP    %r6,27,28,%r4   ;offset 0xdc8
        EXTRU   %r6,3,4,%r7     ;offset 0xdcc
        OR      %r4,%r7,%r6     ;offset 0xdd0
        LDW     32(0,%r25),%r2  ;offset 0xdd4
        AND     %r19,%r6,%r4    ;offset 0xdd8
        EXTRU   %r6,15,16,%r7   ;offset 0xddc
        AND     %r19,%r7,%r6    ;offset 0xde0
        ADD     %r21,%r6,%r5    ;offset 0xde4
        XOR     %r2,%r1,%r2     ;offset 0xde8
        ADD     %r20,%r4,%r4    ;offset 0xdec
        LDW     0(0,%r4),%r4    ;offset 0xdf0
        AND     %r19,%r2,%r6    ;offset 0xdf4
        LDW     0(0,%r5),%r5    ;offset 0xdf8
        ADD     %r22,%r6,%r6    ;offset 0xdfc
        LDW     0(0,%r6),%r6    ;offset 0xe00
        XOR     %r3,%r4,%r7     ;offset 0xe04
        EXTRU   %r2,15,16,%r2   ;offset 0xe08
        XOR     %r7,%r5,%r7     ;offset 0xe0c
        AND     %r19,%r2,%r2    ;offset 0xe10
        XOR     %r7,%r6,%r3     ;offset 0xe14
        ADD     %r28,%r2,%r2    ;offset 0xe18
        LDW     0(0,%r2),%r6    ;offset 0xe1c
        LDW     28(0,%r25),%r4  ;offset 0xe20
        XOR     %r3,%r6,%r3     ;offset 0xe24
        XOR     %r4,%r3,%r4     ;offset 0xe28
        ZDEP    %r4,27,28,%r2   ;offset 0xe2c
        EXTRU   %r4,3,4,%r6     ;offset 0xe30
        OR      %r2,%r6,%r5     ;offset 0xe34
        LDW     24(0,%r25),%r4  ;offset 0xe38
        AND     %r19,%r5,%r2    ;offset 0xe3c
        EXTRU   %r5,15,16,%r6   ;offset 0xe40
        AND     %r19,%r6,%r5    ;offset 0xe44
        XOR     %r4,%r3,%r4     ;offset 0xe48
        ADD     %r20,%r2,%r2    ;offset 0xe4c
        ADD     %r21,%r5,%r7    ;offset 0xe50
        LDW     0(0,%r2),%r2    ;offset 0xe54
        AND     %r19,%r4,%r5    ;offset 0xe58
        EXTRU   %r4,15,16,%r6   ;offset 0xe5c
        LDW     0(0,%r7),%r4    ;offset 0xe60
        ADD     %r22,%r5,%r5    ;offset 0xe64
        LDW     0(0,%r5),%r5    ;offset 0xe68
        XOR     %r1,%r2,%r7     ;offset 0xe6c
        AND     %r19,%r6,%r6    ;offset 0xe70
        ADD     %r28,%r6,%r1    ;offset 0xe74
        XOR     %r7,%r4,%r7     ;offset 0xe78
        LDW     0(0,%r1),%r2    ;offset 0xe7c
        XOR     %r7,%r5,%r4     ;offset 0xe80
        LDW     20(0,%r25),%r5  ;offset 0xe84
        XOR     %r4,%r2,%r4     ;offset 0xe88
        XOR     %r5,%r4,%r5     ;offset 0xe8c
        ZDEP    %r5,27,28,%r7   ;offset 0xe90
        EXTRU   %r5,3,4,%r5     ;offset 0xe94
        LDW     16(0,%r25),%r6  ;offset 0xe98
        OR      %r7,%r5,%r2     ;offset 0xe9c
        AND     %r19,%r2,%r1    ;offset 0xea0
        EXTRU   %r2,15,16,%r5   ;offset 0xea4
        XOR     %r6,%r4,%r2     ;offset 0xea8
        AND     %r19,%r5,%r7    ;offset 0xeac
        EXTRU   %r2,15,16,%r6   ;offset 0xeb0
        ADD     %r21,%r7,%r7    ;offset 0xeb4
        AND     %r19,%r2,%r5    ;offset 0xeb8
        LDW     0(0,%r7),%r2    ;offset 0xebc
        ADD     %r20,%r1,%r1    ;offset 0xec0
        LDW     0(0,%r1),%r1    ;offset 0xec4
        ADD     %r22,%r5,%r7    ;offset 0xec8
        LDW     0(0,%r7),%r5    ;offset 0xecc
        AND     %r19,%r6,%r6    ;offset 0xed0
        XOR     %r3,%r1,%r7     ;offset 0xed4
        ADD     %r28,%r6,%r6    ;offset 0xed8
        LDW     0(0,%r6),%r1    ;offset 0xedc
        XOR     %r7,%r2,%r7     ;offset 0xee0
        LDW     12(0,%r25),%r6  ;offset 0xee4
        XOR     %r7,%r5,%r7     ;offset 0xee8
        XOR     %r7,%r1,%r1     ;offset 0xeec
        XOR     %r6,%r1,%r2     ;offset 0xef0
        ZDEP    %r2,27,28,%r6   ;offset 0xef4
        EXTRU   %r2,3,4,%r2     ;offset 0xef8
        OR      %r6,%r2,%r2     ;offset 0xefc
        AND     %r19,%r2,%r6    ;offset 0xf00
        EXTRU   %r2,15,16,%r2   ;offset 0xf04
        AND     %r19,%r2,%r5    ;offset 0xf08
        ADD     %r20,%r6,%r6    ;offset 0xf0c
        ADD     %r21,%r5,%r7    ;offset 0xf10
        LDW     0(0,%r7),%r5    ;offset 0xf14
        LDW     0(0,%r6),%r2    ;offset 0xf18
        LDW     8(0,%r25),%r7   ;offset 0xf1c
        XOR     %r4,%r2,%r6     ;offset 0xf20
        XOR     %r7,%r1,%r3     ;offset 0xf24
        XOR     %r6,%r5,%r2     ;offset 0xf28
        AND     %r19,%r3,%r4    ;offset 0xf2c
        EXTRU   %r3,15,16,%r6   ;offset 0xf30
        AND     %r19,%r6,%r3    ;offset 0xf34
        ADD     %r22,%r4,%r4    ;offset 0xf38
        LDW     0(0,%r4),%r6    ;offset 0xf3c
        ADD     %r28,%r3,%r5    ;offset 0xf40
        LDW     0(0,%r5),%r3    ;offset 0xf44
        LDW     4(0,%r25),%r7   ;offset 0xf48
        XOR     %r2,%r6,%r5     ;offset 0xf4c
        XOR     %r5,%r3,%r3     ;offset 0xf50
        XOR     %r7,%r3,%r7     ;offset 0xf54
        ZDEP    %r7,27,28,%r4   ;offset 0xf58
        EXTRU   %r7,3,4,%r6     ;offset 0xf5c
        OR      %r4,%r6,%r4     ;offset 0xf60
        LDW     0(0,%r25),%r2   ;offset 0xf64
        AND     %r19,%r4,%r7    ;offset 0xf68
        EXTRU   %r4,15,16,%r25  ;offset 0xf6c
        ADD     %r20,%r7,%r20   ;offset 0xf70
        AND     %r19,%r25,%r7   ;offset 0xf74
        LDW     0(0,%r20),%r25  ;offset 0xf78
        XOR     %r2,%r3,%r2     ;offset 0xf7c
        ADD     %r21,%r7,%r20   ;offset 0xf80
        AND     %r19,%r2,%r6    ;offset 0xf84
        EXTRU   %r2,15,16,%r7   ;offset 0xf88
        LDW     0(0,%r20),%r2   ;offset 0xf8c
        ADD     %r22,%r6,%r20   ;offset 0xf90
        AND     %r19,%r7,%r6    ;offset 0xf94
        LDW     0(0,%r20),%r19  ;offset 0xf98
        XOR     %r1,%r25,%r4    ;offset 0xf9c
        ADD     %r28,%r6,%r1    ;offset 0xfa0
        XOR     %r4,%r2,%r22    ;offset 0xfa4
        LDW     0(0,%r1),%r21   ;offset 0xfa8
        XOR     %r22,%r19,%r25  ;offset 0xfac
        ZDEP    %r3,30,31,%r22  ;offset 0xfb0
        EXTRU   %r3,0,1,%r1     ;offset 0xfb4
        XOR     %r25,%r21,%r20  ;offset 0xfb8
        OR      %r22,%r1,%r4    ;offset 0xfbc
        XOR     %r4,%r20,%r28   ;offset 0xfc0
        AND     %r28,%r29,%r21  ;offset 0xfc4
        XOR     %r20,%r21,%r20  ;offset 0xfc8
        XOR     %r4,%r21,%r3    ;offset 0xfcc
        ZDEP    %r20,30,31,%r22 ;offset 0xfd0
        EXTRU   %r20,0,1,%r4    ;offset 0xfd4
        OR      %r22,%r4,%r4    ;offset 0xfd8
        EXTRU   %r3,23,24,%r5   ;offset 0xfdc
        XOR     %r5,%r4,%r6     ;offset 0xfe0
        AND     %r6,%r24,%r2    ;offset 0xfe4
        XOR     %r4,%r2,%r4     ;offset 0xfe8
        ZDEP    %r2,23,24,%r22  ;offset 0xfec
        XOR     %r3,%r22,%r6    ;offset 0xff0
        EXTRU   %r4,29,30,%r28  ;offset 0xff4
        XOR     %r28,%r6,%r1    ;offset 0xff8
        AND     %r1,%r23,%r23   ;offset 0xffc
        XOR     %r6,%r23,%r20   ;offset 0x1000
        ZDEP    %r23,29,30,%r5  ;offset 0x1004
        XOR     %r4,%r5,%r2     ;offset 0x1008
        EXTRU   %r20,15,16,%r6  ;offset 0x100c
        XOR     %r6,%r2,%r7     ;offset 0x1010
        EXTRU   %r7,31,16,%r24  ;offset 0x1014
        XOR     %r2,%r24,%r4    ;offset 0x1018
        ZDEP    %r7,15,16,%r3   ;offset 0x101c
        XOR     %r20,%r3,%r3    ;offset 0x1020
        EXTRU   %r4,27,28,%r23  ;offset 0x1024
        XOR     %r23,%r3,%r24   ;offset 0x1028
        AND     %r24,%r31,%r1   ;offset 0x102c
        XOR     %r3,%r1,%r29    ;offset 0x1030
        STBS    %r29,0(0,%r26)  ;offset 0x1034
        EXTRU   %r29,23,24,%r19 ;offset 0x1038
        STBS    %r19,1(0,%r26)  ;offset 0x103c
        EXTRU   %r29,15,16,%r3  ;offset 0x1040
        STBS    %r3,2(0,%r26)   ;offset 0x1044
        EXTRU   %r29,7,8,%r28   ;offset 0x1048
        STBS    %r28,3(0,%r26)  ;offset 0x104c
        ZDEP    %r1,27,28,%r20  ;offset 0x1050
        XOR     %r4,%r20,%r22   ;offset 0x1054
        STBS    %r22,4(0,%r26)  ;offset 0x1058
        EXTRU   %r22,23,24,%r21 ;offset 0x105c
        STBS    %r21,5(0,%r26)  ;offset 0x1060
        EXTRU   %r22,15,16,%r25 ;offset 0x1064
        STBS    %r25,6(0,%r26)  ;offset 0x1068
        EXTRU   %r22,7,8,%r1    ;offset 0x106c
        STBS    %r1,7(0,%r26)   ;offset 0x1070
        LDW     -84(0,%r30),%r2 ;offset 0x1074
        LDW     -48(0,%r30),%r7 ;offset 0x1078
        LDW     -52(0,%r30),%r6 ;offset 0x107c
        LDW     -56(0,%r30),%r5 ;offset 0x1080
        LDW     -60(0,%r30),%r4 ;offset 0x1084
        BV      %r0(%r2)        ;offset 0x1088
        .EXIT
        LDWM    -64(0,%r30),%r3 ;offset 0x108c
        .PROCEND ;in=24,25,26;


        .SPACE  $TEXT$
        .SUBSPA $CODE$
        .SUBSPA $CODE$
        .SPACE  $PRIVATE$,SORT=16
        .SUBSPA $DATA$,QUAD=1,ALIGN=8,ACCESS=31,SORT=16
DS$desQuickFips
        .ALIGN  8
        .STRINGZ "$Id: desCore.h,v 1.10 1992/04/16 23:08:44 how E $"
        .BLOCK  2
        .BLOCK  4
        .STRINGZ "$Id: desCode.h,v 1.16 1992/04/17 00:44:43 how E $"
        .BLOCK  2
        .IMPORT $global$,DATA
        .SPACE  $TEXT$
        .SUBSPA $CODE$
        .EXPORT DesQuickFipsEncrypt,ENTRY,PRIV_LEV=3,ARGW0=GR,ARGW1=GR,ARGW2=GR
        .IMPORT des_bigmap,DATA
        .SUBSPA $CODE$
        .EXPORT DesQuickFipsDecrypt,ENTRY,PRIV_LEV=3,ARGW0=GR,ARGW1=GR,ARGW2=GR
        .END
